package com.duben.roseplaylet.manager

import android.content.Intent
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.text.method.ScrollingMovementMethod
import android.view.LayoutInflater
import android.widget.TextView
import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.MintsApplication
import com.duben.roseplaylet.R
import com.duben.roseplaylet.mvp.model.BaseResponse
import com.duben.roseplaylet.mvp.model.WXInfo
import com.duben.roseplaylet.ui.activitys.IMActivity
import com.duben.roseplaylet.utils.LogUtil
import com.duben.roseplaylet.utils.ToastUtil
import com.duben.roseplaylet.utils.UcropUtils
import com.google.gson.JsonObject
import com.tencent.imsdk.v2.V2TIMConversation
import com.tencent.qcloud.tuicore.TUIConfig
import com.tencent.qcloud.tuicore.TUIConstants
import com.tencent.qcloud.tuicore.interfaces.TUICallback
import com.tencent.qcloud.tuikit.timcommon.config.classicui.TUIConfigClassic
import com.tencent.qcloud.tuikit.tuichat.config.classicui.TUIChatConfigClassic
import com.tencent.qcloud.tuikit.tuiconversation.config.classicui.TUIConversationConfigClassic

/**
 *  @author Assen
 *  @date 2025/1/12
 *  @desc
 */
class IMHelper private constructor() {

    init {
        TUIConfig.setTUIHostType(TUIConfig.TUI_HOST_TYPE_IMAPP)
        customSet()
    }

    private var SECRET_KEY =
        "eJw1Tl0LgjAU-S97Dru3bW4TegjpQTJMFKnHwlW3sqZJBNF-b2S9HDifnBcr0yKwT0edZZFELQBg9BUftmMRmwTABn6vz1vnqGYRhj4UGgFycKi21572NBQkoEAPXAAqHxT8P0AH7*vZqcwdv2mdqcqslys4lvl812zSZNzGra5iCZesXxQymf6KPTX*HCoeGuRGwfsDyCExtw__"

    companion object {
        const val IM_SDK_APPID = 1600069405

        val instance: IMHelper by lazy(mode = LazyThreadSafetyMode.SYNCHRONIZED) {
            IMHelper()
        }
    }

    fun getUserSig(): String {
        return SECRET_KEY
    }

    fun getImMsg() {
        val application = MintsApplication.getContext() as MintsApplication
        AppHttpManager.getInstance(application)
            .call(application.loanService.imMsg,
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {}
                    override fun onError(e: Throwable) {}
                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (baseResponse.status == 200) {
                            val psw = baseResponse.data["pass"].asString
                            SECRET_KEY = psw

                            loginIm()
                        }
                    }
                })
    }

    fun customSet() {
        val appContext = MintsApplication.getContext()

        //隐藏更多菜单中选项（全局）
        TUIChatConfigClassic.hideItemsInMoreMenu(TUIChatConfigClassic.CUSTOM)
        //设置会话列表、cell 背景色
        TUIConversationConfigClassic.setListBackground(ColorDrawable(appContext.resources.getColor(R.color.color_07060C)))
        TUIConversationConfigClassic.setCellBackground(ColorDrawable(appContext.resources.getColor(R.color.color_07060C)))
        TUIConversationConfigClassic.setPinnedCellBackground(
            ColorDrawable(appContext.resources.getColor(R.color.color_07060C))
        )
        //展示在线状态
        TUIConversationConfigClassic.setShowUserOnlineStatusIcon(true)
        //展示未读红点
        TUIConversationConfigClassic.setShowCellUnreadCount(true)


        //开启消息已读回执 -旗舰版能用
        // TUIChatConfigClassic.setMessageReadReceiptNeeded(true)
        //设置系统通知消息文字的字体、颜色和背景色，针对所有系统通知消息生效
        TUIChatConfigClassic.setSystemMessageTextColor(Color.WHITE)
        TUIChatConfigClassic.setSystemMessageFontSize(23)
        TUIChatConfigClassic.setSystemMessageBackground(
            ColorDrawable(appContext.resources.getColor(R.color.color_07060C))
        )

        // 聊天界面背景色
        TUIChatConfigClassic.setBackground(ColorDrawable(appContext.resources.getColor(R.color.color_07060C)))
        TUIConfigClassic.setSendBubbleBackground(appContext.resources.getDrawable(R.drawable.shape_bg_market))
        TUIConfigClassic.setReceiveBubbleBackground(appContext.resources.getDrawable(R.drawable.shape_bg_market))
        TUIChatConfigClassic.setSendTextMessageColor(Color.WHITE)
        TUIChatConfigClassic.setReceiveTextMessageColor(Color.BLACK)
    }

    fun setCustomTopView(wxInfo: WXInfo?) {
        val tipsView = LayoutInflater.from(MintsApplication.getContext())
            .inflate(R.layout.custom_tips_view, null)
//        val marqueeView = tipsView.findViewById<MarqueeView<*>>(R.id.marqueeView)
//        val message = "请勿轻易通过第三方账户进行红包、转账、借"
//        marqueeView.startWithText(message)
//        marqueeView.startWithText(
//            message,
//            com.sunfusheng.marqueeview.R.anim.anim_bottom_in,
//            com.sunfusheng.marqueeview.R.anim.anim_top_out
//        )
        val tvTips = tipsView.findViewById<TextView>(R.id.tv_tips)
        tvTips.text = "请勿轻易通过第三方账户进行红包、转账、借款等金钱往来以免上当受骗"
        tvTips.movementMethod = ScrollingMovementMethod()

        val tvWxNo = tipsView.findViewById<TextView>(R.id.tv_wx_no)
        val tvCopy = tipsView.findViewById<TextView>(R.id.tv_copy)
        val tvSend = tipsView.findViewById<TextView>(R.id.tv_send)
        tvCopy.setOnClickListener {
            ToastUtil.show(MintsApplication.getContext(), "微信已复制到剪切板!")
            UcropUtils.clipData(tvWxNo.text.toString())
        }
        tvSend.setOnClickListener {

        }
        TUIChatConfigClassic.setCustomTopView(tipsView)
    }

    private fun loginIm() {
        val instance = UserManager.getInstance()
        val tuiLoginConfig = LoginWrapper.getLoginConfig()
        // tuiLoginConfig.isInitLocalStorageOnly = true
        val userID = instance.userPKID
        val userSig = IMHelper.instance.getUserSig()
        LogUtil.i("LoginWrapper ", "userSig $userSig")
        LoginWrapper.getInstance().loginIMSDK(MintsApplication.getContext(), IMHelper.IM_SDK_APPID,
            userID, userSig, tuiLoginConfig, object : TUICallback() {
                override fun onSuccess() {
                    LogUtil.i("LoginWrapper ", "imLogin onSuccess")
                }

                override fun onError(errorCode: Int, errorMessage: String) {
                    LogUtil.i(
                        "LoginWrapper ",
                        "imLogin errorCode = $errorCode, errorInfo = $errorMessage"
                    )
                }
            })
    }


    fun startChatActivity(chatId: String) {
        val intent = Intent(MintsApplication.getContext(), IMActivity::class.java)
        intent.putExtra(TUIConstants.TUIChat.CHAT_TYPE, V2TIMConversation.V2TIM_C2C)
        intent.putExtra(TUIConstants.TUIChat.CHAT_ID, chatId)
        intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
        MintsApplication.getContext().startActivity(intent)
    }
}