package com.duben.roseplaylet.manager

import android.content.Intent
import com.duben.roseplaylet.MintsApplication
import com.duben.roseplaylet.ui.activitys.BasicUserProfileActivity
import com.duben.roseplaylet.ui.activitys.VipActivity
import com.duben.roseplaylet.ui.widgets.RealAuthDialog
import com.duben.roseplaylet.utils.ToastUtil

class UserHelper private constructor() {

    companion object {
        //缺少基础资料请填写
        const val COMMON_ERROR_CODE_BASIC_PROFILE = 9404

        //无vip或金币
        const val COMMON_ERROR_CODE_NO_VIP = 9405

        //未认证
        const val COMMON_ERROR_CODE_NO_AUTH = 9406

        val instance: UserHelper by lazy(mode = LazyThreadSafetyMode.SYNCHRONIZED) {
            UserHelper()
        }
    }

    private val userInstance by lazy { UserManager.getInstance() }

    //用户是否填写基本资料
    fun isUserHaveBasic(): Boolean {
        if (userInstance.userHasBasic()) {
            return true
        }
        receiveErrorCode(COMMON_ERROR_CODE_BASIC_PROFILE)
        return false
    }

    //用户是否实名
    fun isUserAuth(): Boolean {
        if (userInstance.idcardStatus == 1) {
            return true
        }
        receiveErrorCode(COMMON_ERROR_CODE_NO_AUTH)
        return false
    }

    fun showRealAuthDialog() {
        RealAuthDialog(ActivityPageManager.getInstance().currentActivity).show()
    }

    fun receiveErrorCode(code: Int) {
        val appContext = MintsApplication.getContext()
        val intent: Intent
        when (code) {
            COMMON_ERROR_CODE_BASIC_PROFILE -> {
                // 缺少基础资料
                ToastUtil.show(MintsApplication.getContext(), "缺少基础资料")

                intent = Intent(appContext, BasicUserProfileActivity::class.java)
                intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
                appContext.startActivity(intent)
            }
            COMMON_ERROR_CODE_NO_VIP -> {
                // 无vip或金币
                ToastUtil.show(MintsApplication.getContext(), "余额不足，请充值")

                intent = Intent(appContext, VipActivity::class.java)
                intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
                appContext.startActivity(intent)
            }
            COMMON_ERROR_CODE_NO_AUTH -> {
                // 未认证
                ToastUtil.show(MintsApplication.getContext(), "请完成真人认证")

                showRealAuthDialog()

//                intent = Intent(appContext, RealAuthActivity::class.java)
//                intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
//                appContext.startActivity(intent)
            }
            else -> {}
        }
    }

}