package com.duben.roseplaylet.manager;

import android.text.TextUtils;

import com.duben.roseplaylet.MintsApplication;
import com.duben.roseplaylet.mvp.model.UserBean;
import com.tencent.imsdk.BaseConstants;

import net.grandcentrix.tray.AppPreferences;


/**
 * 描述：管理用户信息
 * 作者：孟崔广
 * 时间：2022/12/22 13:54
 */
public class UserManager {

    private static UserManager _inst;
    private AppPreferences ps;

    /**
     * 游客 or 登录用户
     */
    private static final String IS_TEMP_USER = "is_temp_user";
    /**
     * 用户ID
     */
    private static final String USER_ID = "userId";
    /**
     * 用户PK_ID
     */
    private static final String USER_PK_ID = "userPkId";
    /**
     * 登陆状态ID
     */
    private static final String TOKEN_ID = "tokenId";
    /**
     * 手机号
     */
    private static final String MOBILE = "mobile";
    /**
     * 姓名
     */
    private static final String REAL_NAME = "realName";
    /**
     * 微信id
     */
    private static final String WX_OPENID = "wx_openid";
    /**
     * 头像
     */
    private static final String HEAD_URL = "head_url";
    /**
     * vip是否有效
     */
    private static final String VIP_FLAG = "vipFlag";
    /**
     * vip是否永久
     */
    private static final String VIP_FOREVER = "VIP_FOREVER";

    private static final String VIP_DATE = "VIP_DATE";
    private static final String CODE_ID = "codeId";
    // 匹配用户 = true
    private static final String NEW_FLAG = "new_flag";


    /****************新加****************/
    //分享码
    private static final String SHARE_CODE = "SHARE_CODE";
    //上次IM登录CODE
    private static final String LAST_IM_LOGIN_CODE = "LAST_IM_LOGIN_CODE";
    //用户性别
    private static final String USER_SEX = "USER_SEX";
    //认证状态，1 已认证
    private static final String IDCARD_STATUS = "IDCARD_STATUS";
    //是否填写基础资料
    private static final String HAS_BASE = "HAS_BASE";
    //金币，买各种虚拟资产
    private static final String USER_BEANS = "USER_BEANS";
    //年龄
    private static final String USER_AGE = "USER_AGE";
    //奖励金币
    private static final String USER_REWARD_COIN = "USER_REWARD_COIN";
    //城市
    private static final String USER_CITY = "USER_CITY";
    //头像
    private static final String USER_HEAD_URL = "USER_HEAD_URL";
    //提现支付宝账号 是否设置了
    private static final String USER_ALIPAY_SET = "USER_ALIPAY_SET";

    public static UserManager getInstance() {
        if (_inst == null) {
            _inst = new UserManager();
        }
        return _inst;
    }

    private UserManager() {
        init();
        return;
    }

    private void init() {
        ps = new AppPreferences(MintsApplication.getContext());
    }

    /**
     * 保存用户信息
     */
    public void saveUserInfo(UserBean user) {
        if (ps == null) {
            return;
        }

        String token = user.getToken();

        if (token != null) {
            ps.put(TOKEN_ID, token);
        }

        String uid = String.valueOf(user.getPk_id());
        String mobile = user.getMobile();
        String openid = user.getOpenid();
        if (!TextUtils.isEmpty(mobile) || !TextUtils.isEmpty(openid)) {
            ps.put(IS_TEMP_USER, uid);
        } else {
            ps.remove(IS_TEMP_USER);
        }

        if (user.getExpireTime() > 0) {
            ps.put(VIP_FLAG, true);
        } else {
            ps.put(VIP_FLAG, false);
        }

        ps.put(SHARE_CODE, user.getShareCode());
        ps.put(VIP_FOREVER, user.isForever());
        ps.put(REAL_NAME, user.getNickName());
        ps.put(HEAD_URL, user.getHeaderUrl());
        ps.put(USER_ID, uid);
        ps.put(USER_PK_ID, user.getPk_id());
        ps.put(MOBILE, user.getMobile());
        ps.put(VIP_DATE, user.getExpireTime());
        ps.put(WX_OPENID, openid);
        ps.put(CODE_ID, user.getIdcode());
        ps.put(NEW_FLAG, user.getActiviteFlag() == 1);
        ps.put(USER_SEX, user.getSex());


        ps.put(USER_BEANS, user.getBeans());
        ps.put(USER_REWARD_COIN, user.getRewardCoin());

        ps.put(HAS_BASE, user.isHasBase());
        ps.put(IDCARD_STATUS, user.getIdcardStatus());
        ps.put(SHARE_CODE, user.getShareCode());
    }

    /**
     * 金币
     */
    public int getUserBeans() {
        if (ps == null) {
            return 0;
        }
        return ps.getInt(USER_BEANS, 0);
    }

    /**
     * 奖励金额
     */
    public int getUserRewardCoin() {
        if (ps == null) {
            return 0;
        }
        return ps.getInt(USER_REWARD_COIN, 0);
    }

    /**
     * 判断用户是否认证
     */
    public int getIdcardStatus() {
        if (ps == null) {
            return 0;
        }
        return ps.getInt(IDCARD_STATUS, 0);
    }

    /**
     * 判断用户是否填写基础资料
     */
    public boolean userHasBasic() {
        if (ps == null) {
            return false;
        }
        return ps.getBoolean(HAS_BASE, false);
    }

    /**
     * 单独获取用户id
     */
    public String getMobile() {
        if (ps == null) {
            return null;
        }
        return ps.getString(MOBILE, "");
    }

    public String getName() {
        if (ps == null) {
            return null;
        }
        return ps.getString(REAL_NAME, "");
    }

    public long getVipDate() {
        return ps.getLong(VIP_DATE, 0);
    }

    /**
     * 判断用户是否已登录
     *
     * @return true为已登录   false 为未登录
     */
    public boolean userIsLogin() {
        if (ps == null) {
            return false;
        }
        return !TextUtils.isEmpty(ps.getString(IS_TEMP_USER, ""));
    }

    /**
     * 单独获取用户id
     */
    public String getUserID() {
        if (ps == null) {
            return null;
        }
        return ps.getString(USER_ID, "");
    }

    /**
     * 单独获取用户PKid
     */
    public String getUserPKID() {
        if (ps == null) {
            return null;
        }
        return ps.getString(USER_PK_ID, "");
    }

    public boolean getVipFlag() {
        if (ps == null) {
            return false;
        }
        return ps.getBoolean(VIP_FLAG, false);
    }

    public boolean getNewFlag() {
        if (ps == null) {
            return false;
        }
        return ps.getBoolean(NEW_FLAG, false);
    }

    /**
     * 获取用户登陆状态
     */
    public String getTokenID() {
        if (ps == null) {
            return null;
        }
        return ps.getString(TOKEN_ID, "");
    }

    public String getHead() {
        if (ps == null) {
            return null;
        }
        return ps.getString(HEAD_URL, "");
    }

    public String getWxOpenid() {
        if (ps == null) {
            return null;
        }
        return ps.getString(WX_OPENID, "");
    }

    public String getCodeId() {
        if (ps == null) {
            return null;
        }
        return ps.getString(CODE_ID, "");
    }

    public boolean getVipForever() {
        if (ps == null) {
            return false;
        }
        return ps.getBoolean(VIP_FOREVER, false);
    }

    public void setVipFlag(boolean vipFlag) {
        if (ps == null) {
            return;
        }
        ps.put(VIP_FLAG, vipFlag);
    }

    public String getShareCode() {
        if (ps == null) {
            return null;
        }
        return ps.getString(SHARE_CODE, "");
    }

    public void setLastImLoginCode(int lastImLoginCode) {
        if (ps == null) {
            return;
        }
        ps.put(LAST_IM_LOGIN_CODE, lastImLoginCode);
    }

    public int getLastImLoginCode() {
        if (ps == null) {
            return BaseConstants.ERR_SUCC;
        }
        return ps.getInt(LAST_IM_LOGIN_CODE, BaseConstants.ERR_SUCC);
    }

    public int getUserSex() {
        if (ps == null) {
            return 1;
        }
        return ps.getInt(USER_SEX, 1);
    }

    public void userLogout() {
        if (ps != null) {
            ps.remove(USER_ID);
            ps.remove(MOBILE);
            ps.remove(TOKEN_ID);
            ps.remove(REAL_NAME);
            ps.remove(HEAD_URL);
            ps.remove(IS_TEMP_USER);
            ps.remove(VIP_FLAG);
            ps.remove(VIP_FOREVER);
            ps.remove(WX_OPENID);
            ps.remove(CODE_ID);
            ps.remove(VIP_DATE);
            ps.remove(NEW_FLAG);

            ps.remove(HAS_BASE);
            ps.remove(IDCARD_STATUS);
            ps.remove(SHARE_CODE);
        }

        _inst = null;
    }


}
