package com.duben.roseplaylet.mvp.presenters

import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.manager.AppHttpManager
import com.duben.roseplaylet.mvp.model.BaseResponse
import com.duben.roseplaylet.mvp.views.AlbumView
import com.google.gson.JsonObject

class AlbumPresenter : BasePresenter<AlbumView>() {

    fun getImages() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.getImages({}),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.getImagesFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return
                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message
                        when (code) {
                            200 -> {
                                val ja = baseResponse.data["images"].asJsonArray
                                val imagesList = arrayListOf<String>()
                                ja.forEach {
                                    imagesList.add(it.asString)
                                }
                                view.getImagesSuc(imagesList)
                            }
                            else -> {
                                view.showToast(message)
                                view.getImagesFail()
                            }
                        }
                    }
                })
    }

    fun setImages(images: ArrayList<String> = arrayListOf(), image: String = "", type: Int = 0) {
        val vo = HashMap<String, Any>()
        if (images.isEmpty() && image.isEmpty()) return
        if (images.isNotEmpty()) {
            vo["images"] = images
        } else {
            vo["image"] = image
            vo["type"] = type
        }
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.setImages(vo),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.setImagesFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return
                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message
                        when (code) {
                            200 -> {
                                view.setImagesSuc()
                            }
                            else -> {
                                view.showToast(message)
                                view.setImagesFail()
                            }
                        }
                    }
                })
    }
}