package com.duben.roseplaylet.mvp.presenters

import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.manager.AppHttpManager
import com.duben.roseplaylet.mvp.model.BaseResponse
import com.duben.roseplaylet.mvp.model.UserProfileData
import com.duben.roseplaylet.mvp.views.BasicUserProfileView
import java.util.HashMap

class BasicUserProfilePresenter : BasePresenter<BasicUserProfileView>() {

    fun initBasicInfo(birthday: String, nickName: String, sex: Int, headerUrl: String) {
        val vo = HashMap<String, Any>()
        vo["birthday"] = birthday
        vo["nickName"] = nickName
        vo["sex"] = sex
        vo["headerUrl"] = headerUrl
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.initInfo(vo),
                object : BaseSubscriber<BaseResponse<UserProfileData>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserProfileData>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.initBasicSuc()
                            else -> {
                                view.showToast(message)
                                view.initBasicFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.initBasicFail()
                    }
                })
    }
}