package com.duben.roseplaylet.mvp.presenters

import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.manager.AppHttpManager
import com.duben.roseplaylet.mvp.model.BaseResponse
import com.duben.roseplaylet.mvp.model.UserList
import com.duben.roseplaylet.mvp.views.CommonView
import com.google.gson.JsonObject
import java.util.HashMap

class CommonPresenter : BasePresenter<CommonView>() {

    fun toLike(toUid: String, status: Int) {
        val vo = hashMapOf<String, Any>()
        vo["toUid"] = toUid
        vo["status"] = status
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.toLike(vo), object : BaseSubscriber<BaseResponse<JsonObject>>() {
                override fun onCompleted() {
                    if (isLinkView) return
                    view.hideLoading()
                }

                override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                    if (isLinkView) return

                    view.hideLoading()
                    val code = baseResponse.status
                    val message = baseResponse.message

                    when (code) {
                        200 -> {}
                        else -> {
                            view.showToast(message)
                        }
                    }
                }

                override fun onError(e: Throwable?) {
                    if (isLinkView) return
                    view.hideLoading()
                    view.showToast(e?.message)
                }

            })
    }


    fun getILikeList(page: Int, size: Int) {
        val vo = HashMap<String, Any>()
        vo["page"] = page
        vo["size"] = size
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.getILikeList(vo),
                object : BaseSubscriber<BaseResponse<UserList>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.getCommonDataFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserList>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.getCommonDataSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast(message)
                                view.getCommonDataFail()
                            }
                        }
                    }
                })
    }

    fun getLikeMeList(page: Int, size: Int) {
        val vo = HashMap<String, Any>()
        vo["page"] = page
        vo["size"] = size
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.getLikeMeList(vo),
                object : BaseSubscriber<BaseResponse<UserList>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.getCommonDataFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserList>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.getCommonDataSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast(message)
                                view.getCommonDataFail()
                            }
                        }
                    }
                })
    }

    fun getSeeMeList(page: Int, size: Int) {
        val vo = HashMap<String, Any>()
        vo["page"] = page
        vo["size"] = size
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.getSeeMeList(vo),
                object : BaseSubscriber<BaseResponse<UserList>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.getCommonDataFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserList>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.getCommonDataSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast(message)
                                view.getCommonDataFail()
                            }
                        }
                    }
                })
    }

}