package com.duben.roseplaylet.mvp.presenters

import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.manager.AppHttpManager
import com.duben.roseplaylet.mvp.model.*
import com.duben.roseplaylet.mvp.views.DrawCashView
import com.google.gson.JsonObject
import java.util.HashMap

class DrawCashPresenter : BasePresenter<DrawCashView>() {

    fun getVipProducts() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.vipProducts, object : BaseSubscriber<BaseResponse<VipBean>>() {
                override fun onCompleted() {
                    if (isLinkView) return
                    view.hideLoading()
                }

                override fun onNext(baseResponse: BaseResponse<VipBean>) {
                    if (isLinkView) return

                    view.hideLoading()
                    val code = baseResponse.status
                    val message = baseResponse.message

                    when (code) {
                        200 -> {
                            view.getVipProductSuc(baseResponse.data)
                        }
                        else -> {
                            view.getCashouBaseMsgFail()
                            view.showToast(message)
                        }
                    }
                }

                override fun onError(e: Throwable?) {
                    if (isLinkView) return
                    view.hideLoading()
                    view.showToast(e?.message)
                    view.getCashouBaseMsgFail()
                }

            })
    }

    fun getCashouBaseMsg() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.cashouBaseMsg, object : BaseSubscriber<BaseResponse<DrawCashBean>>() {
                override fun onCompleted() {
                    if (isLinkView) return
                    view.hideLoading()
                }

                override fun onNext(baseResponse: BaseResponse<DrawCashBean>) {
                    if (isLinkView) return

                    view.hideLoading()
                    val code = baseResponse.status
                    val message = baseResponse.message

                    when (code) {
                        200 -> {
                            view.getCashouBaseMsgSuc(baseResponse.data)
                        }
                        else -> {
                            view.getCashouBaseMsgFail()
                            view.showToast(message)
                        }
                    }
                }

                override fun onError(e: Throwable?) {
                    if (isLinkView) return
                    view.hideLoading()
                    view.showToast(e?.message)
                    view.getCashouBaseMsgFail()
                }

            })
    }

    fun getAlipayMsg() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.alipayMsg, object : BaseSubscriber<BaseResponse<AlipayMsgBean>>() {
                override fun onCompleted() {
                    if (isLinkView) return
                    view.hideLoading()
                }

                override fun onNext(baseResponse: BaseResponse<AlipayMsgBean>) {
                    if (isLinkView) return

                    view.hideLoading()
                    val code = baseResponse.status
                    val message = baseResponse.message
                    when (code) {
                        200 -> {
                            view.getAlipayMsgSuc(baseResponse.data)
                        }
                        else -> {
                            view.showToast(message)
                        }
                    }
                }

                override fun onError(e: Throwable?) {
                    if (isLinkView) return
                    view.hideLoading()
                    view.showToast(e?.message)
                }

            })
    }

    fun addCashoutReq(cash: String) {
        val vo = HashMap<String, Any>()
        vo["cash"] = cash
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.addCashoutReq(vo),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.addCashoutReqFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.addCashoutReqSuc()
                            }
                            else -> {
                                view.showToast(message)
                                view.addCashoutReqFail()
                            }
                        }
                    }
                })
    }

    fun updateAlipayMsg(alipayAccount: String, idcardName: String, idcard: String) {
        val vo = HashMap<String, Any>()
        vo["alipayAccount"] = alipayAccount
        vo["idcardName"] = idcardName
        vo["idcard"] = idcard
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.updateAlipayMsg(vo),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.updateAlipayMsgFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.updateAlipayMsgSuc()
                            }
                            else -> {
                                view.showToast(message)
                                view.updateAlipayMsgFail()
                            }
                        }
                    }
                })
    }

    fun getVipPayParams(payChannel: String, pid: String, enter: String) {
        val vo = HashMap<String, Any>()
        vo["payChannel"] = payChannel
        vo["pid"] = pid
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.getVipPayParams(vo),
                object : BaseSubscriber<BaseResponse<WxPayParamBean>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e.message)
                    }

                    override fun onNext(baseResponse: BaseResponse<WxPayParamBean>) {
                        if (isLinkView) return
                        val code: Int = baseResponse.getStatus()
                        when (code) {
                            200 -> {
                                view.getVipPayParamsSuc(payChannel, baseResponse.data, enter)
                            }
                            else -> {
                                view.showToast(baseResponse.message)
                            }
                        }
                    }
                })
    }


    fun queryVipOrder(tid: String, isPay: Boolean) {
        val vo = HashMap<String, Any>()
        vo["tid"] = tid
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.queryVipOrder(vo),
                object : BaseSubscriber<BaseResponse<Any>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<Any>) {
                        if (isLinkView) return
                        val code: Int = baseResponse.status
                        when (code) {
                            200 -> {
                                view.queryVipOrderSuc(isPay)
                            }
                        }
                    }
                })
    }

    fun payError(code: Int) {
        val vo = HashMap<String, Any>()
        vo["code"] = code
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.payError(vo),
                object : BaseSubscriber<BaseResponse<Any>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<Any>) {
                        if (isLinkView) return
                        val code: Int = baseResponse.status
                    }
                })
    }

}