package com.duben.roseplaylet.mvp.presenters

import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.manager.AppHttpManager
import com.duben.roseplaylet.mvp.model.BaseResponse
import com.duben.roseplaylet.mvp.model.UserProfileData
import com.duben.roseplaylet.mvp.model.UserProfileDataInfo
import com.duben.roseplaylet.mvp.views.EditProfileView
import java.util.HashMap

class EditProfilePresenter : BasePresenter<EditProfileView>() {

    fun getUserInfo() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.userInfo,
                object : BaseSubscriber<BaseResponse<UserProfileDataInfo>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserProfileDataInfo>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.getUserInfoSuc(baseResponse.data)
                            else -> {
                                view.showToast(message)
                                view.getUserInfoFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.getUserInfoFail()
                    }
                })
    }

    fun setUserInfo(userProfileData: UserProfileData) {
        val vo = HashMap<String, Any>()
        vo["info"] = userProfileData
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.setUserInfo(vo),
                object : BaseSubscriber<BaseResponse<UserProfileData>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserProfileData>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.setUserInfoSuc()
                            else -> {
                                view.showToast(message)
                                view.setUserInfoFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.setUserInfoFail()
                    }
                })
    }


}