package com.duben.roseplaylet.mvp.presenters

import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.manager.AppHttpManager
import com.duben.roseplaylet.mvp.model.BaseResponse
import com.duben.roseplaylet.mvp.model.ShareRankList
import com.duben.roseplaylet.mvp.views.InviteView
import com.google.gson.JsonObject

class InvitePresenter : BasePresenter<InviteView>() {

    fun getSharePageMsg() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.sharePageMsg,
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.getSharePageMsgFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.getSharePageMsgSuc(
                                    baseResponse.data.get("shareCode").asString,
                                    baseResponse.data.get("rUserShareCode").asString
                                )
                            }
                            else -> {
                                view.showToast(message)
                                view.getSharePageMsgFail()
                            }
                        }
                    }
                })
    }


    fun getShareOrders() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.shareOrders,
                object : BaseSubscriber<BaseResponse<ShareRankList>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.getShareOrderFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<ShareRankList>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.getShareOrderSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast(message)
                                view.getShareOrderFail()
                            }
                        }
                    }
                })
    }

    fun getShareUrl() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.shareUrl,
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.getShareUrlSucFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.getShareUrlSuc(baseResponse.data.get("url").asString)
                            }
                            else -> {
                                view.showToast(message)
                                view.getShareUrlSucFail()
                            }
                        }
                    }
                })
    }

    fun getRuserShareCode() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.ruserShareCode,
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.showToast(e.message)
                        view.getShareUrlSucFail()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
//                                view.getShareUrlSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast(message)
                                view.getShareUrlSucFail()
                            }
                        }
                    }
                })
    }


}