package com.duben.roseplaylet.mvp.presenters

import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.manager.AppHttpManager
import com.duben.roseplaylet.mvp.model.*
import com.duben.roseplaylet.mvp.views.RealAuthView
import com.google.gson.JsonObject
import java.util.HashMap

class RealAuthPresenter : BasePresenter<RealAuthView>() {

    fun getUserInfo() {
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.userInfo,
                object : BaseSubscriber<BaseResponse<UserProfileDataInfo>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserProfileDataInfo>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.getUserInfoSuc(baseResponse.data)
                            else -> {
                                view.showToast(message)
                                view.getUserInfoFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.getUserInfoFail()
                    }
                })
    }

    fun setUserInfo(userProfileData: UserProfileData) {
        val vo = HashMap<String, Any>()
        vo["info"] = userProfileData
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.setUserInfo(vo),
                object : BaseSubscriber<BaseResponse<UserProfileData>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserProfileData>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.setUserInfoSuc()
                            else -> {
                                view.showToast(message)
                                view.setUserInfoFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.setUserInfoFail()
                    }
                })
    }

    fun setWechatQRCode(qrCode: String) {
        val vo = hashMapOf<String, Any>()
        vo["qrCode"] = qrCode
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.setWechatQRCode(vo),
                object : BaseSubscriber<BaseResponse<FaceParam>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<FaceParam>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {}
                            else -> {
                                view.showToast(message)
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                    }
                })
    }

    fun getFaceParam(imgUrl: String) {
        val vo = hashMapOf<String, Any>()
        vo["imgUrl"] = imgUrl
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.getFaceParam(vo),
                object : BaseSubscriber<BaseResponse<FaceParam>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<FaceParam>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.getFaceParamSuc(baseResponse.data)
                            else -> {
                                view.showToast(message)
                                view.getFaceParamFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.getFaceParamFail()
                    }
                })
    }

    fun faceResult(faceResult: FaceResult) {
        val vo = hashMapOf<String, Any>()
        vo["success"] = faceResult.isSuccess
        vo["domain"] = faceResult.domain
        vo["code"] = faceResult.code
        vo["desc"] = faceResult.desc
        vo["reason"] = faceResult.reason
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.getFaceResult(vo),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.faceResultSuc()
                            else -> {
                                view.showToast(message)
                                view.faceResultFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.faceResultFail()
                    }
                })
    }

}