package com.duben.roseplaylet.mvp.presenters

import com.duben.library.net.neterror.BaseSubscriber
import com.duben.library.net.neterror.Throwable
import com.duben.roseplaylet.manager.AppHttpManager
import com.duben.roseplaylet.mvp.model.*
import com.duben.roseplaylet.mvp.views.UserProfileView
import com.google.gson.JsonObject

class UserProfilePresenter : BasePresenter<UserProfileView>() {

    fun toLike(toUid: String, status: Int) {
        val vo = hashMapOf<String, Any>()
        vo["toUid"] = toUid
        vo["status"] = status
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.toLike(vo), object : BaseSubscriber<BaseResponse<JsonObject>>() {
                override fun onCompleted() {
                    if (isLinkView) return
                    view.hideLoading()
                }

                override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                    if (isLinkView) return

                    view.hideLoading()
                    val code = baseResponse.status
                    val message = baseResponse.message

                    when (code) {
                        200 -> {
                            var toLikeStatus = 0
                            if (status == 0) {
                                toLikeStatus = 1
                            }
                            view.toLikeSuc(toLikeStatus)
                        }
                        else -> {
                            view.showToast(message)
                        }
                    }
                }

                override fun onError(e: Throwable?) {
                    if (isLinkView) return
                    view.hideLoading()
                    view.showToast(e?.message)
                }

            })
    }

    fun getMorePage(toUid: String) {
        val vo = hashMapOf<String, Any>()
        vo["toUid"] = toUid
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.getMorePage(vo),
                object : BaseSubscriber<BaseResponse<UserProfileData>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<UserProfileData>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.getMorePageSuc(baseResponse.data)
                            else -> {
                                view.showToast(message)
                                view.getMorePageFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.getMorePageFail()
                    }
                })
    }

    fun seeWechat(toUid: String) {
        val vo = hashMapOf<String, Any>()
        vo["toUid"] = toUid
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.seeWechat(vo),
                object : BaseSubscriber<BaseResponse<SeeWechat>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<SeeWechat>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.seeWechatSuc(baseResponse.data)
                            else -> {
                                view.showToast(message)
                                view.seeWechatFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.seeWechatFail()
                    }
                })
    }

    fun unlockInfoByCoin(toUid: String) {
        val vo = hashMapOf<String, Any>()
        vo["toUid"] = toUid
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.unlockInfoByCoin(vo),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.unlockInfoByCoinSuc()
                            else -> {
                                view.showToast(message)
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                    }
                })
    }


    fun unlockWechat(toUid: String) {
        val vo = hashMapOf<String, Any>()
        vo["toUid"] = toUid
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.unlockWechat(vo),
                object : BaseSubscriber<BaseResponse<NineListBean>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<NineListBean>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> view.unlockWechatSuc()
                            else -> {
                                view.showToast(message)
                                view.unlockWechatFail()
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                        view.getMorePageFail()
                    }
                })
    }

    fun toBlack(toUid: String) {
        val vo = hashMapOf<String, Any>()
        vo["toUid"] = toUid
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.setBlack(vo),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.toBlackSuc()
                            }
                            else -> {
                                view.showToast(message)
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                    }
                })
    }


    fun toWhite(toUid: String) {
        val vo = hashMapOf<String, Any>()
        vo["toUid"] = toUid
        AppHttpManager.getInstance(loanApplication)
            .call(loanService.setWhite(vo),
                object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return

                        view.hideLoading()
                        val code = baseResponse.status
                        val message = baseResponse.message

                        when (code) {
                            200 -> {
                                view.toWhiteSuc()
                            }
                            else -> {
                                view.showToast(message)
                            }
                        }
                    }

                    override fun onError(e: Throwable?) {
                        if (isLinkView) return
                        view.hideLoading()
                        view.showToast(e?.message)
                    }
                })
    }
}