package com.duben.roseplaylet.net;

import android.content.Context;
import android.text.TextUtils;

import com.duben.roseplaylet.mvp.model.AlipayMsgBean;
import com.duben.roseplaylet.mvp.model.DrawCashBean;
import com.duben.roseplaylet.mvp.model.FaceParam;
import com.duben.roseplaylet.mvp.model.HallList;
import com.duben.roseplaylet.mvp.model.RecommendBannerList;
import com.duben.roseplaylet.mvp.model.SeeWechat;
import com.duben.roseplaylet.mvp.model.ShareRankList;
import com.duben.roseplaylet.mvp.model.UserList;
import com.duben.roseplaylet.mvp.model.UserProfileData;
import com.duben.roseplaylet.mvp.model.UserProfileDataInfo;
import com.google.gson.JsonObject;
import com.duben.roseplaylet.BuildConfig;
import com.duben.roseplaylet.mvp.model.BannerList;
import com.duben.roseplaylet.mvp.model.BaseResponse;
import com.duben.roseplaylet.mvp.model.HotStyleTypesList;
import com.duben.roseplaylet.mvp.model.IndexList;
import com.duben.roseplaylet.mvp.model.NineListBean;
import com.duben.roseplaylet.mvp.model.NineShowBean;
import com.duben.roseplaylet.mvp.model.OrderRecordBean;
import com.duben.roseplaylet.mvp.model.RecoBean;
import com.duben.roseplaylet.mvp.model.UserBean;
import com.duben.roseplaylet.mvp.model.Version;
import com.duben.roseplaylet.mvp.model.VipBean;
import com.duben.roseplaylet.mvp.model.WxPayParamBean;
import com.duben.roseplaylet.utils.AESUtils;
import com.orhanobut.logger.Logger;

import java.util.Map;
import java.util.concurrent.TimeUnit;

import okhttp3.OkHttpClient;
import okhttp3.logging.HttpLoggingInterceptor;
import retrofit2.Retrofit;
import retrofit2.adapter.rxjava.RxJavaCallAdapterFactory;
import retrofit2.http.Body;
import retrofit2.http.POST;
import rx.Observable;

/**
 * 描述：服务器交互
 * 作者：孟崔广
 */
public interface LoanService {

    /**
     * 更新版本
     *
     * @return
     */
    @POST("appNa/checkUpgrade")
    Observable<BaseResponse<Version>> checkUpgrade(@Body Map<String, Object> vo);

    /**
     * 游客登录
     *
     * @return
     */
    @POST("roseApi/user/visitorlogin")
    Observable<BaseResponse<UserBean>> visitorlogin(@Body Map<String, Object> vo);

    /**
     * 获取验证码
     *
     * @return
     */
    @POST("roseApi/user/sendMobileCode")
    Observable<BaseResponse<Object>> sendMobileCode(@Body Map<String, Object> vo);

    /**
     * 登录
     *
     * @return
     */
    @POST("roseApi/user/mobilelogin")
    Observable<BaseResponse<UserBean>> login(@Body Map<String, Object> vo);

    /**
     * 微信登录
     *
     * @return
     */
    @POST("api/user/wechatlogin")
    Observable<BaseResponse<UserBean>> wechatlogin(@Body Map<String, Object> vo);

    /**
     * 提交设备信息
     *
     * @return
     */
    @POST("roseApi/user/saveTerminalInfo")
    Observable<BaseResponse<Object>> saveTerminalInfo(@Body Map<String, Object> vo);

    /**
     * 查询vip产品
     */
    @POST("roseApi/vip/getVipProducts/rose")
    Observable<BaseResponse<VipBean>> getVipProducts();

    /**
     * 查询失败
     *
     * @return
     */
    @POST("api/vip/payError")
    Observable<BaseResponse<Object>> payError(@Body Map<String, Object> vo);

    /**
     * 获取支付参数
     *
     * @return
     */
    @POST("roseApi/vip/getVipPayParams/rose")
    Observable<BaseResponse<WxPayParamBean>> getVipPayParams(@Body Map<String, Object> vo);

    /**
     * 查询vip订单
     *
     * @return
     */
    @POST("api/vip/queryVipOrder")
    Observable<BaseResponse<Object>> queryVipOrder(@Body Map<String, Object> vo);

    /**
     * 订单记录
     *
     * @return
     */
    @POST("api/vip/getOrderList")
    Observable<BaseResponse<OrderRecordBean>> getCashOutRecords();

    /**
     * 我的
     *
     * @return
     */
    @POST("roseApi/user/baseMsg")
    Observable<BaseResponse<UserBean>> getBaseMsg(@Body Map<String, Object> vo);

    /**
     * 申请退款
     *
     * @return
     */
    @POST("api/vip/reqfundV1")
    Observable<BaseResponse<JsonObject>> reqfundV1(@Body Map<String, Object> vo);

    /**
     * 取消自动续费
     *
     * @return
     */
    @POST("api/vip/unSign")
    Observable<BaseResponse<JsonObject>> unSign();

    /**
     * groMore激励视频展示广告提交数据
     *
     * @return
     */
    @POST("api/vedioV1/unlockByAd")
    Observable<BaseResponse<IndexList>> unlock(@Body Map<String, Object> vo);

    /**
     * 首页分类
     *
     * @return
     */
    @POST("api/vedioV1/types")
    Observable<BaseResponse<HotStyleTypesList>> getHomeV1Types();

    /**
     * 首页列表
     *
     * @return
     */
    @POST("api/vedioV1/listByType")
    Observable<BaseResponse<BannerList>> getHomeV1List(@Body Map<String, Object> vo);

    /**
     * 用户反馈
     *
     * @return
     */
    @POST("api/vedioV1/feedback")
    Observable<BaseResponse<Object>> feedback(@Body Map<String, Object> vo);

    /**
     * 轮播图
     *
     * @return
     */
    @POST("api/vedioV1/topTabs/v0821")
    Observable<BaseResponse<BannerList>> topTabs();

    /**
     * 排行榜
     *
     * @return
     */
    @POST("api/vedioV1/orders")
    Observable<BaseResponse<BannerList>> orders();

    /**
     * 剧情列表
     *
     * @return
     */
    @POST("api/vedioV1/getIndexList")
    Observable<BaseResponse<IndexList>> getIndexList(@Body Map<String, Object> vo);

    /**
     * 优选剧 剧情列表
     *
     * @return
     */
    @POST("api/vedioV1/getIndexList")
    Observable<BaseResponse<IndexList>> getIndexList2(@Body Map<String, Object> vo);

    /**
     * 播放链接
     *
     * @return
     */
    @POST("api/vedioV1/getIndex")
    Observable<BaseResponse<Object>> getIndex(@Body Map<String, Object> vo);

    /**
     * 收藏
     *
     * @return
     */
    @POST("api/vedioV1/collect")
    Observable<BaseResponse<Object>> collect(@Body Map<String, Object> vo);

    /**
     * 取消收藏
     *
     * @return
     */
    @POST("api/vedioV1/cancelCollect")
    Observable<BaseResponse<Object>> cancelCollect(@Body Map<String, Object> vo);

    /**
     * 收藏记录
     *
     * @return
     */
    @POST("api/vedioV1/collectList")
    Observable<BaseResponse<BannerList>> collectList();

    /**
     * 最新一条记录
     *
     * @return
     */
    @POST("api/url/newestRecord")
    Observable<BaseResponse<Object>> newestRecord();

    /**
     * 历史记录
     *
     * @return
     */
    @POST("api/vedioV1/history")
    Observable<BaseResponse<BannerList>> history();

    /**
     * 提交视频信息
     */
    @POST("api/vedioV1/reportIndex")
    Observable<BaseResponse<Object>> reportIndex(@Body Map<String, Object> vo);

    /**
     * 推荐
     */
    @POST("api/vedioV1/autoList")
    Observable<BaseResponse<BannerList>> autoList();

    /**
     * 穿山甲上传剧集
     */
    @POST("api/vedioV1/initCsj")
    Observable<BaseResponse<Object>> commitCsjShotInfo(@Body Map<String, Object> vo);

    /**
     * 推荐
     */
    @POST("api/vedioV1/firstVedio")
    Observable<BaseResponse<IndexList>> getSoltVedio();

    /**
     * 匹配推荐
     */
    @POST("api/vedioV1/vedio3Msg")
    Observable<BaseResponse<RecoBean>> getRecommendVedio();

    /**
     * 9宫格信息
     */
    @POST("api/vedioV1/getTurnConfig")
    Observable<BaseResponse<NineListBean>> getTurnConfig();

    /**
     * 9宫格抽奖
     */
    @POST("api/vedioV1/toTurn")
    Observable<BaseResponse<NineListBean.NineBean>> toTurn();

    /**
     * 是否展示9宫格
     */
    @POST("api/vedioV1/showTurn")
    Observable<BaseResponse<NineShowBean>> showTurn();

    /**
     * 获取推荐状态
     */
    @POST("api/vedioV1/showVedio4")
    Observable<BaseResponse<JsonObject>> firstShowVedio();

    /**
     * 推荐banner
     */
    @POST("api/vedioV1/vedio4Msg")
    Observable<BaseResponse<RecommendBannerList>> vedio4Msg(@Body Map<String, Object> vo);

    /**
     * Vip尊享剧场
     */
    @POST("api/vedioV1/vedio4List")
    Observable<BaseResponse<BannerList>> vedio4List(@Body Map<String, Object> vo);

    /**
     * 调用事件
     *
     * @return
     */
    @POST("api/vedioV1/reportOpenAdEcpm")
    Observable<BaseResponse<Object>> cmtEcpm(@Body Map<String, Object> vo);

    /**
     * 视频页广告开关
     */
    @POST("api/vedioV1/confs")
    Observable<BaseResponse<JsonObject>> showVedioConfs();

    /**
     * 视频页广告开关
     */
    @POST("api/vip/signAfterSeconds")
    Observable<BaseResponse<JsonObject>> signAfterSeconds();

    /**
     * <<<<<<< Updated upstream
     * 支付宝获取授权
     */
    @POST("api/user/getAlipayAuthUrl")
    Observable<BaseResponse<JsonObject>> getAlipayAuthUrl(@Body Map<String, Object> vo);

    /**
     * 风控标记
     */
    @POST("api/user/reportAlipayMsg")
    Observable<BaseResponse<Object>> reportAlipayMsg(@Body Map<String, Object> vo);

    /**
     * 获得活体sdk初始化参数
     */
    @POST("roseApi/face/getFaceParam")
    Observable<BaseResponse<FaceParam>> getFaceParam(@Body Map<String, Object> vo);

    /**
     * 更新用户实名认证状态
     */
    @POST("roseApi/user/updateIdcardStatus")
    Observable<BaseResponse<JsonObject>> updateIdcardStatus(@Body Map<String, Object> vo);

    /**
     * 通知服务端活体完成，在sdk的回调中触发
     */
    @POST("roseApi/face/faceResult")
    Observable<BaseResponse<JsonObject>> getFaceResult(@Body Map<String, Object> vo);

    /**
     * 进入同城，拉取同城列表信息接口
     */
    @POST("roseApi/hall/hallList")
    Observable<BaseResponse<HallList>> getHallList(@Body Map<String, Object> vo);

    /**
     * 基础资料
     */
    @POST("roseApi/user/initInfo")
    Observable<BaseResponse<JsonObject>> initInfo(@Body Map<String, Object> vo);

    /**
     * 定位和定位上传接口
     */
    @POST("roseApi/user/saveGps")
    Observable<BaseResponse<JsonObject>> saveGps(@Body Map<String, Object> vo);

    /**
     * 同城喜欢
     */
    @POST("roseApi/hall/like")
    Observable<BaseResponse<JsonObject>> toLike(@Body Map<String, Object> vo);

    /**
     * 二级资料页
     */
    @POST("roseApi/hall/morePage")
    Observable<BaseResponse<UserProfileData>> getMorePage(@Body Map<String, Object> vo);

    /**
     * 查看微信号
     */
    @POST("roseApi/hall/seeWechat")
    Observable<BaseResponse<SeeWechat>> seeWechat(@Body Map<String, Object> vo);

    /**
     * 金币解锁和免费次数解锁同一接口
     */
    @POST("roseApi/hall/unlockWechat")
    Observable<BaseResponse<JsonObject>> unlockWechat(@Body Map<String, Object> vo);

    /**
     * 查看资料
     */
    @POST("roseApi/user/info")
    Observable<BaseResponse<UserProfileDataInfo>> getUserInfo();

    /**
     * 编辑资料
     */
    @POST("roseApi/user/setInfo")
    Observable<BaseResponse<UserProfileData>> setUserInfo(@Body Map<String, Object> vo);

    /**
     * 我喜欢的
     */
    @POST("roseApi/hall/ilikeList")
    Observable<BaseResponse<UserList>> getILikeList(@Body Map<String, Object> vo);

    /**
     * 喜欢我的
     */
    @POST("roseApi/hall/likeMeList")
    Observable<BaseResponse<UserList>> getLikeMeList(@Body Map<String, Object> vo);

    /**
     * 看过我的
     */
    @POST("roseApi/hall/seeMeList")
    Observable<BaseResponse<UserList>> getSeeMeList(@Body Map<String, Object> vo);

    /**
     * 用金币解锁用户资料
     */
    @POST("roseApi/hall/unlockInfoByCoin")
    Observable<BaseResponse<JsonObject>> unlockInfoByCoin(@Body Map<String, Object> vo);

    /**
     * 拉黑 拉白
     */
    @POST("roseApi/hall/black")
    Observable<BaseResponse<JsonObject>> setBlack(@Body Map<String, Object> vo);

    /**
     * 拉黑 拉白
     */
    @POST("roseApi/hall/white")
    Observable<BaseResponse<JsonObject>> setWhite(@Body Map<String, Object> vo);

    /**
     * 获取im信息
     */
    @POST("roseApi/user/getImMsg")
    Observable<BaseResponse<JsonObject>> getImMsg();

    /**
     * 分享链接（二维码地址）
     */
    @POST("roseApi/share/shareUrl")
    Observable<BaseResponse<JsonObject>> getShareUrl();

    /**
     * 邀请页基础信息
     */
    @POST("roseApi/share/sharePageMsg")
    Observable<BaseResponse<JsonObject>> getSharePageMsg();

    /**
     * 邀请页排行榜
     */
    @POST("roseApi/share/orders")
    Observable<BaseResponse<ShareRankList>> getShareOrders();

    /**
     * 修改邀请我的分享码
     */
    @POST("roseApi/user/updateRuserShareCode")
    Observable<BaseResponse<JsonObject>> updateRuserShareCode(@Body Object obj);

    /**
     * 是否已经绑定分享码
     */
    @POST("roseApi/user/getRuserShareCode")
    Observable<BaseResponse<JsonObject>> getRuserShareCode();

    /**
     * 查看图片
     */
    @POST("roseApi/user/getImages")
    Observable<BaseResponse<JsonObject>> getImages(@Body Object obj);

    /**
     * 设置图片
     */
    @POST("roseApi/user/setImages")
    Observable<BaseResponse<JsonObject>> setImages(@Body Map<String, Object> vo);

    /**
     * 提现页面接口
     */
    @POST("roseApi/share/getCashouBaseMsg")
    Observable<BaseResponse<DrawCashBean>> getCashouBaseMsg();

    /**
     * 提现接口
     */
    @POST("roseApi/share/addCashoutReq")
    Observable<BaseResponse<JsonObject>> addCashoutReq(@Body Map<String, Object> vo);

    /**
     * 获取当前支付宝信息
     */
    @POST("roseApi/user/getAlipayMsg")
    Observable<BaseResponse<AlipayMsgBean>> getAlipayMsg();

    /**
     * 绑定支付宝信息/修改支付宝信息
     */
    @POST("roseApi/user/updateAlipayMsg")
    Observable<BaseResponse<JsonObject>> updateAlipayMsg(@Body Map<String, Object> vo);

    /**
     * 上传微信二维码
     */
    @POST("roseApi/user/setWechatQRCode")
    Observable<BaseResponse<JsonObject>> setWechatQRCode(@Body Map<String, Object> vo);

    /**
     * 用户页基本信息
     */
    @POST("roseApi/hall/userHallMsg")
    Observable<BaseResponse<JsonObject>> getUserHallMsg();

    /**
     * 默认http工厂
     */
    class Factory {
        public static LoanService create(Context context) {

            OkHttpClient.Builder builder = new OkHttpClient.Builder();

            builder.retryOnConnectionFailure(true);
            builder.connectTimeout(20, TimeUnit.SECONDS);
            builder.readTimeout(20, TimeUnit.SECONDS);
            builder.writeTimeout(20, TimeUnit.SECONDS);

//            if (BuildConfig.DEBUG) {
//                HttpLoggingInterceptor logging = new HttpLoggingInterceptor();
//                logging.setLevel(HttpLoggingInterceptor.Level.BODY);
//                builder.interceptors().add(logging);
//            }

            if (BuildConfig.DEBUG) {
                HttpLoggingInterceptor logging = new HttpLoggingInterceptor(message -> {
                    if (TextUtils.isEmpty(message)) return;
                    String s = message.substring(0, 1);
                    String request = message.substring(0, 4);
                    if ("{".equals(s) || "[".equals(s)) {
                        Logger.json(message);
                    } else if (request.contains("-->") || request.contains("<--")) {
                        Logger.d("Method" + message);
                    } else {
                        Logger.d("params:" + message);
                    }
                });
                logging.setLevel(HttpLoggingInterceptor.Level.BODY);
                builder.interceptors().add(logging);
            }

            OkHttpInterceptor okHttpInterceptor = new OkHttpInterceptor(AESUtils.getDefaultKey());
            builder.interceptors().add(okHttpInterceptor);

            Retrofit retrofit = new Retrofit.Builder()
                    .client(builder.build())
                    .baseUrl(BuildConfig.MainIp)
                    .addConverterFactory(GsonConverterFactory.create())
                    .addCallAdapterFactory(RxJavaCallAdapterFactory.create())
                    .build();


            return retrofit.create(LoanService.class);
        }
    }
}
