package com.duben.roseplaylet.ui.activitys

import android.Manifest
import android.app.Activity
import android.app.Dialog
import android.content.Intent
import android.content.pm.ActivityInfo
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.TextUtils
import android.view.View
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.OssType
import com.duben.roseplaylet.manager.OssManager
import com.duben.roseplaylet.mvp.presenters.AlbumPresenter
import com.duben.roseplaylet.mvp.views.AlbumView
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.roseplaylet.ui.preview.ImagePreviewActivity
import com.duben.roseplaylet.ui.widgets.DeletePhotoConfirmDialog
import com.duben.roseplaylet.ui.widgets.DialogListener
import com.duben.roseplaylet.ui.widgets.nineImage.AddImagesInfo
import com.duben.roseplaylet.ui.widgets.nineImage.AddImagesView
import com.duben.roseplaylet.utils.GlideEngine
import com.luck.picture.lib.PictureSelector
import com.luck.picture.lib.compress.Luban
import com.luck.picture.lib.config.PictureConfig
import com.luck.picture.lib.config.PictureMimeType
import com.luck.picture.lib.entity.LocalMedia
import com.luck.picture.lib.style.PictureWindowAnimationStyle
import com.luck.picture.lib.thread.PictureThreadUtils
import com.luck.picture.lib.tools.DateUtils
import com.tbruyelle.rxpermissions.RxPermissions
import com.yalantis.ucrop.UCrop
import kotlinx.android.synthetic.main.activity_album.*
import kotlinx.android.synthetic.main.header_layout.*
import java.io.File

class AlbumActivity : BaseActivity(), View.OnClickListener, AlbumView {

    companion object {
        const val MAX_ALBUM_SIZE = 6
    }

    private var mCanUploadMax = MAX_ALBUM_SIZE
    private var mUploadCount = 0
    private lateinit var mWindowAnimationStyle: PictureWindowAnimationStyle

    private var mOssList = arrayListOf<String>()
    private val albumPresenter by lazy { AlbumPresenter() }

    override fun getContentViewLayoutID() = R.layout.activity_album

    override fun initViewsAndEvents() {
        albumPresenter.attachView(this)

        mWindowAnimationStyle = PictureWindowAnimationStyle()
        mWindowAnimationStyle.ofAllAnimation(
            com.luck.picture.lib.R.anim.picture_anim_up_in,
            com.luck.picture.lib.R.anim.picture_anim_down_out
        )

        albumPresenter.getImages()
        initView()
    }

    private fun initView() {
        tv_title.text = "我的相册"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        iv_left_icon.setOnClickListener(this)
        line.visibility = View.GONE

        aiv.enableCloseView(false)
        aiv.setAddImagesViewListener(object : AddImagesView.AddImagesViewListener {
            override fun onAdd() {
                showAlbum()
            }

            override fun onDelete(position: Int) {}

            override fun onLongClick(item: AddImagesInfo?) {
                DeletePhotoConfirmDialog(this@AlbumActivity, object : DialogListener() {
                    override fun onClick(dialog: Dialog?, v: View?) {
                        super.onClick(dialog, v)
                        dialog?.dismiss()
                        if (v?.id == R.id.tv_confirm) {
                            aiv.deleteImage(item)
                            // 删除图片
                            albumPresenter.setImages(arrayListOf(), item?.imgUrl.toString(), 2)
                        }
                    }
                }).show()
            }

            override fun onPreview(position: Int, lists: List<AddImagesInfo>?) {
                lists?.let {
                    val preData = arrayListOf<String>()
                    for (info in it) {
                        preData.add(info.imgUrl.toString())
                    }
                    val bundle = Bundle()
                    bundle.putStringArrayList(ImagePreviewActivity.IMAGE_PREVIEW_DATA, preData)
                    bundle.putInt(ImagePreviewActivity.IMAGE_PREVIEW_POSITION, position)
                    readyGo(ImagePreviewActivity::class.java, bundle)
                }
            }
        })
    }

    override fun isApplyKitKatTranslucency() = false

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
        }
    }

    private fun showAlbum() {
        mCanUploadMax = MAX_ALBUM_SIZE - aiv.getAddImages().size
        RxPermissions(this)
            .request(Manifest.permission.READ_EXTERNAL_STORAGE, Manifest.permission.CAMERA)
            .subscribe { granted: Boolean ->
                if (granted) {
                    PictureSelector.create(this)
                        .openGallery(PictureMimeType.ofImage())
                        .theme(R.style.picture_WeChat_style) // 微信主题色
                        .isWeChatStyle(true) // 微信样式
                        .isCamera(false) //列表是否显示拍照按钮
                        .isZoomAnim(false)//图片选择缩放效果
                        .isEnableCrop(true)//是否开启裁剪
                        .setPictureWindowAnimationStyle(mWindowAnimationStyle)
                        .withAspectRatio(2, 4)
                        .isCompress(true)//是否压缩
                        .compressFocusAlpha(true)//压缩后是否保持图片的透明通道
                        .minimumCompressSize(200)// 小于多少kb的图片不压缩
                        .compressQuality(60)//图片压缩后输出质量
                        .synOrAsy(true)//开启同步or异步压缩
                        .maxSelectNum(mCanUploadMax)
                        .setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_UNSPECIFIED)//屏幕旋转方向
                        .selectionMode(PictureConfig.MULTIPLE)//单选or多选
                        .imageEngine(GlideEngine.createGlideEngine())// 图片加载引擎
                        .forResult(PictureConfig.CHOOSE_REQUEST)
                } else {
                    showMissingPermissionDialog("存储")
                }
            }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (resultCode == Activity.RESULT_OK) {
            when (requestCode) {
                // 相册获取图片
                PictureConfig.CHOOSE_REQUEST -> {
                    val selectList: List<LocalMedia> = PictureSelector.obtainMultipleResult(data)
                    mUploadCount = selectList.size
                    mOssList.clear()
                    luban(selectList)
                }
            }
        } else if (resultCode == UCrop.RESULT_ERROR) {
            showToast("裁剪失败，请再试一下")
        }
    }


    /**
     * 鲁班压缩
     */
    private fun luban(images: List<LocalMedia>) {
        runOnUiThread {
            showLoading("正在上传中...")
        }

        val newFileName = DateUtils.getCreateFileName("IMG_CMP_") + ".jpeg"

        PictureThreadUtils.executeByIo(object : PictureThreadUtils.SimpleTask<List<File>>() {
            @Throws(Exception::class)
            override fun doInBackground(): List<File> {
                return Luban.with(mContext)
                    .loadMediaData<LocalMedia>(images)
                    .ignoreBy(200)
                    .isCamera(false)
                    .setCompressQuality(80)
                    .setTargetDir(null)
                    .setFocusAlpha(false)
                    .setNewCompressFileName(newFileName).get()
            }

            override fun onSuccess(files: List<File>) {
                for (file in files) {
                    uploadOss(file.path, OssType.ALBUM.type)
                }
            }

            override fun onFail(t: Throwable?) {
                super.onFail(t)
                hideLoading()
                showToast("网络出小差了！")
            }
        })
    }

    /**
     * 上传到oss服务器
     */
    private fun uploadOss(localFile: String, type: String) {
        OssManager.instance?.run {
            uploadImg(type, localFile)
            setOssUploadImgListener(object : OssManager.OssUploadImgListener {
                override fun uploadImgFailForSubthread(errorInfo: String) {
                    runOnUiThread {
                        showToast(errorInfo)
                    }
                }

                override fun uploadImgSuccessForSubthread(imgPath: String?) {
                    runOnUiThread {
                        if (TextUtils.isEmpty(imgPath)) {
                            showToast("图片异常，请重新添加")
                            return@runOnUiThread
                        }
                        hideLoading()
                        mOssList.add(imgPath!!)

                        if (mOssList.size == mUploadCount) {
                            val imgList = arrayListOf<AddImagesInfo>()
                            for (ossUrl in mOssList) {
                                val addImagesInfo = AddImagesInfo(ossUrl, "2")
                                imgList.add(addImagesInfo)
                            }
                            aiv.addAddImages(imgList)

                            Handler(Looper.getMainLooper()).postDelayed({
                                val uploadImages = arrayListOf<String>()
                                for (image in aiv.getAddImages()) {
                                    uploadImages.add(image.imgUrl.toString())
                                }
                                albumPresenter.setImages(uploadImages)
                            }, 1000)
                        }
                    }
                }
            })
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        albumPresenter.detachView()
    }

    override fun getImagesSuc(data: List<String>) {
        val imgList = arrayListOf<AddImagesInfo>()
        for (s in data) {
            val addImagesInfo = AddImagesInfo(s, "2")
            imgList.add(addImagesInfo)
        }
        aiv.addAddImages(imgList)
    }

    override fun getImagesFail() {

    }

    override fun setImagesSuc() {

    }

    override fun setImagesFail() {
    }
}