package com.duben.roseplaylet.ui.activitys

import android.Manifest
import android.app.Activity
import android.content.Intent
import android.content.pm.ActivityInfo
import android.graphics.Color
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import com.duben.library.utils.GlideUtils
import com.duben.roseplaylet.R
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.common.OssType
import com.duben.roseplaylet.common.UserProfile
import com.duben.roseplaylet.manager.OssManager
import com.duben.roseplaylet.mvp.model.PickBean
import com.duben.roseplaylet.mvp.presenters.BasicUserProfilePresenter
import com.duben.roseplaylet.mvp.views.BasicUserProfileView
import com.duben.roseplaylet.ui.widgets.pick.SinglePickDialog
import com.duben.roseplaylet.utils.GlideEngine
import com.duben.roseplaylet.utils.UcropUtils
import com.luck.picture.lib.PictureSelector
import com.luck.picture.lib.compress.Luban
import com.luck.picture.lib.config.PictureConfig
import com.luck.picture.lib.config.PictureMimeType
import com.luck.picture.lib.entity.LocalMedia
import com.luck.picture.lib.style.PictureWindowAnimationStyle
import com.luck.picture.lib.thread.PictureThreadUtils
import com.luck.picture.lib.tools.DateUtils
import com.luck.picture.lib.tools.SdkVersionUtils
import com.tbruyelle.rxpermissions.RxPermissions
import com.yalantis.ucrop.UCrop
import kotlinx.android.synthetic.main.activity_basic_user_profile.*
import kotlinx.android.synthetic.main.dialog_nine_continue.*
import kotlinx.android.synthetic.main.header_layout.*
import java.io.File

/**
 * 描述：基础信息
 */
class BasicUserProfileActivity : BaseActivity(), View.OnClickListener, BasicUserProfileView {

    private var mSinglePickDialog: SinglePickDialog? = null

    private var avatarUrl: String? = null

    private var sex: Int = -1

    private val basicUserProfilePresenter by lazy { BasicUserProfilePresenter() }

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
    }

    override fun getContentViewLayoutID() = R.layout.activity_basic_user_profile

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        basicUserProfilePresenter.attachView(this)
        tv_title.text = "完善资料"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        line.visibility = View.GONE

        initView()
        initListener()
    }

    private fun initView() {
        rg_sex.setOnCheckedChangeListener { _, checkedId ->
            sex = if (checkedId == rb_female.id) {
                2
            } else {
                1
            }
        }
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.iv_avatar -> {
                showAlbum()
            }
            R.id.tv_age -> {
                showAgePickDialog()
            }
            R.id.tv_save -> {
                val nickname = et_nickname.text.toString()
                val age = tv_age.text.toString()
                if (TextUtils.isEmpty(avatarUrl)) {
                    showToast("请上传头像！")
                    return
                }
                if (TextUtils.isEmpty(nickname)) {
                    showToast("请输入昵称！")
                    return
                }
                if (TextUtils.isEmpty(age)) {
                    showToast("请输入年龄！")
                    return
                }
                if (sex == 1 || sex == 2) {
                    showToast("请选择性别！")
                    return
                }

                basicUserProfilePresenter.initBasicInfo("$age-1-1", nickname, sex, avatarUrl!!)
            }
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tv_save.setOnClickListener(this)
        tv_age.setOnClickListener(this)
        iv_avatar.setOnClickListener(this)
    }

    private fun showAgePickDialog() {
        mSinglePickDialog = SinglePickDialog(
            this, UserProfile.PROFILE_NL.str,
            getAgePickerData(),
            ""
        )
        mSinglePickDialog?.setPickResultListener(object :
            SinglePickDialog.OnPickResultListener {
            override fun onPickResult(result: String) {
                tv_age.text = result
            }
        })
        mSinglePickDialog?.show()
    }

    private fun getAgePickerData(): MutableList<PickBean> {
        val arr = UserProfile.PROFILE_NL.arr
        val data = mutableListOf<PickBean>()
        if (arr != null) {
            for (stringDatum in arr) {
                data.add(PickBean(stringDatum, false))
            }
        }
        return data
    }

    override fun onDestroy() {
        basicUserProfilePresenter.detachView()
        super.onDestroy()
    }

    override fun initBasicSuc() {
        finish()
    }

    override fun initBasicFail() {}

    private fun showAlbum() {
        val windowAnimationStyle = PictureWindowAnimationStyle()
        windowAnimationStyle.ofAllAnimation(
            com.luck.picture.lib.R.anim.picture_anim_up_in,
            com.luck.picture.lib.R.anim.picture_anim_down_out
        )

        RxPermissions(this)
            .request(Manifest.permission.READ_EXTERNAL_STORAGE)
            .subscribe { granted: Boolean ->
                if (granted) {
                    val isEnableCrop = true
                    PictureSelector.create(this)
                        .openGallery(PictureMimeType.ofImage())
                        .theme(R.style.picture_WeChat_style) // 微信主题色
                        .isWeChatStyle(true) // 微信样式
                        .isCamera(true) //列表是否显示拍照按钮
                        .isZoomAnim(false)//图片选择缩放效果
                        .isEnableCrop(isEnableCrop)//是否开启裁剪
                        .setPictureWindowAnimationStyle(windowAnimationStyle)
                        .withAspectRatio(4, 4)
                        .isCompress(true)//是否压缩
                        .compressFocusAlpha(false)//压缩后是否保持图片的透明通道
                        .minimumCompressSize(200)// 小于多少kb的图片不压缩
                        .compressQuality(60)//图片压缩后输出质量
                        .synOrAsy(true)//开启同步or异步压缩
                        .maxSelectNum(10)
                        .setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_UNSPECIFIED)//屏幕旋转方向
                        .selectionMode(PictureConfig.SINGLE)//单选or多选
                        .imageEngine(GlideEngine.createGlideEngine())// 图片加载引擎
                        .forResult(PictureConfig.CHOOSE_REQUEST)
                } else {
                    showMissingPermissionDialog("存储")
                }
            }
    }

    /**
     * 鲁班压缩
     */
    private fun luban(cutPath: String) {
        val media = LocalMedia(cutPath, 0, false, 1, 0, PictureMimeType.ofImage())
        media.cutPath = cutPath
        if (SdkVersionUtils.checkedAndroid_Q()) {
            media.androidQToPath = cutPath
        }

        runOnUiThread {
            showLoading("加载中...")
        }

        val newFileName = DateUtils.getCreateFileName("IMG_CMP_") + ".jpeg"

        PictureThreadUtils.executeByIo(object : PictureThreadUtils.SimpleTask<List<File>>() {
            @Throws(Exception::class)
            override fun doInBackground(): List<File> {
                return Luban.with(mContext)
                    .loadMediaData<LocalMedia>(arrayListOf(media))
                    .ignoreBy(200)
                    .isCamera(false)
                    .setCompressQuality(80)
                    .setTargetDir(null)
                    .setFocusAlpha(false)
                    .setNewCompressFileName(newFileName).get()
            }

            override fun onSuccess(files: List<File>) {
                uploadOss(files[0].path, OssType.PHOTO.type)
            }

            override fun onFail(t: Throwable?) {
                super.onFail(t)
                hideLoading()
            }
        })
    }

    /**
     * 上传到oss服务器
     */
    private fun uploadOss(localFile: String, type: String) {
        OssManager.instance?.run {
            uploadImg(type, localFile)
            setOssUploadImgListener(object : OssManager.OssUploadImgListener {
                override fun uploadImgFailForSubthread(errorInfo: String) {
                    runOnUiThread {
                        showToast(errorInfo)
                    }
                }

                override fun uploadImgSuccessForSubthread(imgPath: String?) {
                    runOnUiThread {
                        if (TextUtils.isEmpty(imgPath)) {
                            showToast("图片异常，请重新添加")
                            return@runOnUiThread
                        }
                        avatarUrl = imgPath!!
                        GlideUtils.loadImageView(
                            this@BasicUserProfileActivity,
                            avatarUrl,
                            iv_avatar
                        )
                    }
                }
            })
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        when (resultCode) {
            Activity.RESULT_OK -> {
                when (requestCode) {
                    // 相册获取图片
                    PictureConfig.CHOOSE_REQUEST -> {
                        val selectList: List<LocalMedia> =
                            PictureSelector.obtainMultipleResult(data)
                        val img = selectList[0]
                        uploadOss(img.compressPath, OssType.PHOTO.type)
                    }
                    // 裁剪获取图片
                    UcropUtils.UCROP_REQUEST_CODE -> {
                        data?.let {
                            val uri = UCrop.getOutput(it)
                            luban(uri?.path!!)
                        }
                    }
                }
            }
            UCrop.RESULT_ERROR -> {
                showToast("裁剪失败，请再试一下")
            }
        }
    }

}
