package com.duben.roseplaylet.ui.activitys

import android.graphics.Color
import android.text.TextUtils
import android.view.View
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.mvp.model.AlipayMsgBean
import com.duben.roseplaylet.mvp.model.DrawCashBean
import com.duben.roseplaylet.mvp.model.VipBean
import com.duben.roseplaylet.mvp.model.WxPayParamBean
import com.duben.roseplaylet.mvp.presenters.DrawCashPresenter
import com.duben.roseplaylet.mvp.views.DrawCashView
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import kotlinx.android.synthetic.main.activity_bind_alipay.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 *  @author Assen
 *  @date 2024/1/8
 *  @desc 绑定支付宝
 */
class BindAliPayActivity : BaseActivity(), View.OnClickListener, DrawCashView {

    private val drawCashPresenter by lazy { DrawCashPresenter() }

    override fun getContentViewLayoutID() = R.layout.activity_bind_alipay

    override fun initViewsAndEvents() {
        drawCashPresenter.attachView(this)

        initHeader()
        initView()
        initListener()
    }

    private fun initView() {}

    private fun initHeader() {
        tv_title.text = "绑定账号"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        line.visibility = View.GONE
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        btn_submit.setOnClickListener(this)
    }

    override fun isApplyKitKatTranslucency() = false

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.btn_submit -> {
                // 绑定支付宝
                val account = et_account.text.toString()
                val name = et_name.text.toString()
                val idcard_no = et_idcard_no.text.toString()

                if (TextUtils.isEmpty(account)) {
                    showToast("请填写支付宝账号")
                    return
                }

                if (TextUtils.isEmpty(name)) {
                    showToast("请填写您的真实姓名")
                    return
                }

                if (TextUtils.isEmpty(idcard_no)) {
                    showToast("请填写真实身份证号")
                    return
                }

                drawCashPresenter.updateAlipayMsg(account, name, idcard_no)
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        drawCashPresenter.detachView()
    }

    override fun getVipProductSuc(data: VipBean) {}

    override fun getCashouBaseMsgSuc(data: DrawCashBean) {}

    override fun getCashouBaseMsgFail() {}

    override fun addCashoutReqSuc() {}

    override fun addCashoutReqFail() {}

    override fun getAlipayMsgSuc(data: AlipayMsgBean) {}

    override fun getAlipayMsgFail() {}

    override fun queryVipOrderSuc(isPay: Boolean) {}

    override fun getVipPayParamsSuc(payChannel: String, data: WxPayParamBean, enter: String) {}

    override fun updateAlipayMsgSuc() {
        showToast("支付宝绑定成功！")
        finish()
    }

    override fun updateAlipayMsgFail() {}

}