package com.duben.roseplaylet.ui.activitys

import android.graphics.Color
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.manager.UserManager
import com.duben.roseplaylet.mvp.model.UserList
import com.duben.roseplaylet.mvp.presenters.CommonPresenter
import com.duben.roseplaylet.mvp.views.CommonView
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.roseplaylet.ui.adapter.CommonListAdapter
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnLoadMoreListener
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.activity_common_data.*
import kotlinx.android.synthetic.main.header_layout.*

class CommonDataActivity : BaseActivity(), View.OnClickListener, OnRefreshListener, CommonView,
    OnLoadMoreListener {

    private var mType = 0
    private var page = 1 // 分页
    private var pageSize = Constant.PAGE_SIZE // 分页
    private lateinit var commonListAdapter: CommonListAdapter
    private val commonPresenter by lazy { CommonPresenter() }

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            mType = it.getInt(Constant.USER_COMMON_DATA_TYPE, 0)
        }
    }

    override fun getContentViewLayoutID() = R.layout.activity_common_data

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        commonPresenter.attachView(this)

        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        line.visibility = View.GONE

        when (mType) {
            0 -> {
                // 我喜欢的
                tv_title.text = "我喜欢的"
            }
            1 -> {
                // 喜欢我的
                tv_title.text = "喜欢我的"
            }
            2 -> {
                // 看过我的
                tv_title.text = "看过我的"
                if (!UserManager.getInstance().vipFlag && UserManager.getInstance().userSex == 1) {
                    tv_see_vip.visibility = View.VISIBLE
                }
            }
        }

        initRecy()
        initListener()
        srl_data.autoRefresh()
    }

    private fun initRecy() {
        commonListAdapter = CommonListAdapter()
        if (mType == 2 && !UserManager.getInstance().vipFlag) {
            commonListAdapter.setIsBlur(true)
            commonListAdapter.setIsLike(false)
        } else {
            commonListAdapter.setIsBlur(false)
            commonListAdapter.setIsLike(true)
        }
        commonListAdapter.animationEnable = false
        rv_data.layoutManager = LinearLayoutManager(this)
        rv_data.adapter = commonListAdapter
        val emptyView = LayoutInflater.from(this).inflate(R.layout.item_empty_data, null)
        commonListAdapter.setEmptyView(emptyView)
        commonListAdapter.setOnItemClickListener { _, _, position ->
            val bundle = Bundle()
            if (mType == 2) {
                if (UserManager.getInstance().userSex == 1) {
                    if (UserManager.getInstance().vipFlag) {
                        bundle.putString(
                            Constant.TO_UID,
                            commonListAdapter.data[position].uid.toString()
                        )
                        readyGo(UserProfileActivity::class.java, bundle)
                    } else {
                        readyGo(VipActivity::class.java)
                    }
                } else {
                    bundle.putString(
                        Constant.TO_UID,
                        commonListAdapter.data[position].uid.toString()
                    )
                    readyGo(UserProfileActivity::class.java, bundle)
                }
                return@setOnItemClickListener
            }
            bundle.putString(Constant.TO_UID, commonListAdapter.data[position].uid.toString())
            readyGo(UserProfileActivity::class.java, bundle)
        }
        commonListAdapter.setOnClickLikeListener(object : CommonListAdapter.OnClickLikeListener {
            override fun onClickLike(position: Int) {
                commonPresenter.toLike(
                    commonListAdapter.data[position].uid.toString(),
                    commonListAdapter.data[position].likeStatus
                )
            }
        })
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.tv_see_vip -> {
                readyGo(VipActivity::class.java)
            }
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tv_see_vip.setOnClickListener(this)

        srl_data.setEnableRefresh(true)
        srl_data.setOnLoadMoreListener(this)
        srl_data.setOnRefreshListener(this)
    }

    override fun onDestroy() {
        super.onDestroy()
        commonPresenter.detachView()
    }

    private fun loadData() {
        when (mType) {
            0 -> {
                // 我喜欢的
                commonPresenter.getILikeList(page, pageSize)
            }
            1 -> {
                // 喜欢我的
                commonPresenter.getLikeMeList(page, pageSize)
            }
            2 -> {
                // 看过我的
                commonPresenter.getSeeMeList(page, pageSize)
            }
        }
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        page = 1
        loadData()
    }

    override fun onLoadMore(refreshLayout: RefreshLayout) {
        page = ++page
        loadData()
    }

    override fun getCommonDataSuc(data: UserList) {
        srl_data.finishRefresh(true)

        if (::commonListAdapter.isInitialized) {
            if (page == 1) {
                if (data.list.size > 0 && mType == 2) {
                    // 谁看过我
                    tv_see_count.visibility = View.VISIBLE
                    if (data.list.size > 10) {
                        tv_see_count.text = "10+位小姐姐对你感兴趣"
                    } else {
                        tv_see_count.text = "" + data.list.size + "位小姐姐对你感兴趣"
                    }
                } else if (data.list.size > 0 && (mType == 0 || mType == 1)) {
                    tv_tips.visibility = View.VISIBLE
                }

                srl_data.finishRefresh(true)
                commonListAdapter.setNewInstance(data.list)
            } else {
                if (data.list.size < pageSize) {
                    srl_data.finishLoadMoreWithNoMoreData()
                } else {
                    srl_data.finishLoadMore()
                }
                commonListAdapter.addData(data.list)
            }
        }
    }

    override fun getCommonDataFail() {}

}