package com.duben.roseplaylet.ui.activitys

import android.graphics.Color
import android.text.Editable
import android.text.TextUtils
import android.text.TextWatcher
import android.view.View
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.mvp.model.AlipayMsgBean
import com.duben.roseplaylet.mvp.model.DrawCashBean
import com.duben.roseplaylet.mvp.model.VipBean
import com.duben.roseplaylet.mvp.model.WxPayParamBean
import com.duben.roseplaylet.mvp.presenters.DrawCashPresenter
import com.duben.roseplaylet.mvp.views.DrawCashView
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import kotlinx.android.synthetic.main.activity_drawcash.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 *  @author Assen
 *  @date 2024/1/8
 *  @desc 提现
 */
class DrawCashActivity : BaseActivity(), View.OnClickListener, DrawCashView {

    private var maxInput = 0
    private var minInput = 0

    private var drawCashType = Constant.ALI_DRAW_CASH// 提现类型

    private val drawCashPresenter by lazy { DrawCashPresenter() }

    override fun getContentViewLayoutID() = R.layout.activity_drawcash

    override fun initViewsAndEvents() {
        drawCashPresenter.attachView(this)

        initHeader()
        initView()
        initListener()

        drawCashPresenter.getAlipayMsg()
        drawCashPresenter.getCashouBaseMsg()
    }

    private fun initView() {
        et_draw_cash.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {

            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {

            }

            override fun afterTextChanged(s: Editable?) {
                val inputSize = s.toString().length
                if (inputSize < minInput) {
//                    et_draw_cash.setText(minInput)
                    showToast("" + minInput + "元起提现！")
                } else if (inputSize > maxInput) {
//                    et_draw_cash.setText(maxInput)
                    showToast("最多可提现" + maxInput + "元！")
                }
            }
        })
    }

    private fun initHeader() {
        tv_title.text = "我的收益"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        line.visibility = View.GONE
        tv_right.visibility = View.VISIBLE
        tv_right.text = "明细"
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tv_right.setOnClickListener(this)
        btn_drawcash.setOnClickListener(this)
        tv_all_balance.setOnClickListener(this)
        ll_draw_cash_alipay.setOnClickListener(this)
        ll_draw_cash_wx.setOnClickListener(this)
    }

    override fun isApplyKitKatTranslucency() = false

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.tv_right -> {

            }
            R.id.btn_drawcash -> {
                // 提现
                drawCashPresenter.addCashoutReq(et_draw_cash.text.toString())
            }
            R.id.tv_all_balance -> {
                et_draw_cash.setText("" + maxInput)
            }
            R.id.ll_draw_cash_alipay -> {
                // 绑定支付宝
                readyGo(BindAliPayActivity::class.java)
            }
            R.id.ll_draw_cash_wx -> {
            }
        }
    }

    private fun setDrawCashContent(type: String, isBind: Boolean) {
        if (TextUtils.equals(type, Constant.WECHAT_DRAW_CASH)) {
            drawCashType = Constant.WECHAT_DRAW_CASH
            iv_draw_cash_wx.setImageResource(R.mipmap.ic_vip_enable_blue)
            iv_draw_cash_alipay.setImageResource(R.mipmap.ic_vip_none)
            if (isBind) {
                tv_bind_alipay.text = "已绑定"
            }
        } else {
            drawCashType = Constant.ALI_DRAW_CASH
            iv_draw_cash_alipay.setImageResource(R.mipmap.ic_vip_enable_blue)
            iv_draw_cash_wx.setImageResource(R.mipmap.ic_vip_none)
            if (isBind) {
                tv_bind_wx.text = "已绑定"
            }
        }
    }

    override fun getVipProductSuc(data: VipBean) {}

    override fun getCashouBaseMsgSuc(data: DrawCashBean) {
        tv_balance.text = "" + data.canCashoutMoney
        tv_cash.text = "" + data.frozenMoney
        if (data.cashOutMinLimit == 0) {
            minInput = 0
            maxInput = 0
        } else {
            minInput = data.miniLimit
            maxInput = data.cashOutMinLimit
        }

        et_draw_cash.setText("" + data.miniLimit)
    }

    override fun getCashouBaseMsgFail() {}

    override fun addCashoutReqSuc() {

    }

    override fun addCashoutReqFail() {}

    override fun getAlipayMsgSuc(data: AlipayMsgBean) {
        if (data.alipayAccount > 0) {
            setDrawCashContent(Constant.ALI_DRAW_CASH, true)
        } else {
            setDrawCashContent(Constant.ALI_DRAW_CASH, false)
        }
    }

    override fun getAlipayMsgFail() {}

    override fun queryVipOrderSuc(isPay: Boolean) {}

    override fun getVipPayParamsSuc(payChannel: String, data: WxPayParamBean, enter: String) {}

    override fun updateAlipayMsgSuc() {}

    override fun updateAlipayMsgFail() {}

}