package com.duben.roseplaylet.ui.activitys

import android.Manifest
import android.app.Activity
import android.content.Intent
import android.content.pm.ActivityInfo
import android.graphics.Color
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import android.widget.EditText
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.bigkoo.pickerview.builder.OptionsPickerBuilder
import com.duben.library.utils.GlideUtils
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.common.OssType
import com.duben.roseplaylet.common.UserProfile
import com.duben.roseplaylet.manager.OssManager
import com.duben.roseplaylet.mvp.model.*
import com.duben.roseplaylet.mvp.presenters.EditProfilePresenter
import com.duben.roseplaylet.mvp.views.EditProfileView
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.roseplaylet.ui.adapter.ProfileLabelAdapter
import com.duben.roseplaylet.ui.widgets.pick.SinglePickDialog
import com.duben.roseplaylet.utils.AddressData
import com.duben.roseplaylet.utils.GlideEngine
import com.duben.roseplaylet.utils.JobData
import com.duben.roseplaylet.utils.UcropUtils
import com.google.gson.Gson
import com.luck.picture.lib.PictureSelector
import com.luck.picture.lib.compress.Luban
import com.luck.picture.lib.config.PictureConfig
import com.luck.picture.lib.config.PictureMimeType
import com.luck.picture.lib.entity.LocalMedia
import com.luck.picture.lib.style.PictureWindowAnimationStyle
import com.luck.picture.lib.thread.PictureThreadUtils
import com.luck.picture.lib.tools.DateUtils
import com.luck.picture.lib.tools.SdkVersionUtils
import com.tbruyelle.rxpermissions.RxPermissions
import com.yalantis.ucrop.UCrop
import kotlinx.android.synthetic.main.activity_edit_profile.*
import kotlinx.android.synthetic.main.header_layout.*
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.MainScope
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import java.io.File

class EditProfileActivity : BaseActivity(), View.OnClickListener, EditProfileView {

    private lateinit var ivAvatar: ImageView
    private lateinit var tvNickname: EditText
    private lateinit var tvSign: TextView
    private lateinit var tvAge: TextView
    private lateinit var tvJob: TextView
    private lateinit var tvHeight: TextView
    private lateinit var tvWeight: TextView
    private lateinit var tvJyfw: TextView

    // 女性独有资料
    private lateinit var etWechat: EditText
    private lateinit var tvSx: TextView

    // 男性独有资料
    private lateinit var tvJyjm: TextView
    private lateinit var tvXhdnstz: TextView

    private var jobOptions1Items: MutableList<JobBean>? = mutableListOf()
    private var jopOptions2Items: MutableList<ArrayList<String>>? = mutableListOf()

    private var addressOptions1Items: MutableList<JsonBean>? = mutableListOf()
    private var addressOptions2Items: MutableList<ArrayList<String>>? = mutableListOf()

    private var gxbqAdapter: ProfileLabelAdapter? = null
    private var xhdnstzAdapter: ProfileLabelAdapter? = null

    private var avatarUrl = ""

    private var toUid = ""
    private var userProfileData: UserProfileData? = null

    private val gson by lazy { Gson() }

    private val editProfilePresenter by lazy { EditProfilePresenter() }

    override fun getContentViewLayoutID() = R.layout.activity_edit_profile

    override fun isApplyKitKatTranslucency() = false

    private var mSinglePickDialog: SinglePickDialog? = null

    override fun initViewsAndEvents() {
        editProfilePresenter.attachView(this)
        tv_title.text = "编辑资料"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        line.visibility = View.GONE

        initJobData()
        initAddressData()

        editProfilePresenter.getUserInfo()

        initView()
        initListener()
    }

    private fun initJobData() {
        MainScope().launch {
            withContext(Dispatchers.IO) {
                val jobData = JobData.getJsonData(this@EditProfileActivity)
                try {
                    jobOptions1Items = jobData.options1Items
                    jopOptions2Items = jobData.options2Items
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        }
    }

    private fun initAddressData() {
        MainScope().launch {
            withContext(Dispatchers.IO) {
                val addressData = AddressData.getJsonData(this@EditProfileActivity)
                try {
                    addressOptions1Items = addressData.options1Items as ArrayList<JsonBean>
                    addressOptions2Items = addressData.options2Items as ArrayList<ArrayList<String>>
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        }
    }

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            toUid = it.getString(Constant.TO_UID, "")
        }
    }

    private fun initData() {
        userProfileData?.let {
            if (it.sex == 1) {
                initMale()
                tvJyjm.text = it.interest
                if (!TextUtils.isEmpty(it.tagsCommon)) {
                    val tagsList = gson.fromJson(it.tagsCommon, Array<String>::class.java)
                    gxbqAdapter?.setNewInstance(tagsList.toCollection(ArrayList()))
                }
            } else {
                initFemale()
            }

            if (!TextUtils.isEmpty(it.findDescribe)) {
                val tagsList = gson.fromJson(it.findDescribe, Array<String>::class.java)
                xhdnstzAdapter?.setNewInstance(tagsList.toCollection(ArrayList()))
            }
            GlideUtils.loadImageView(this@EditProfileActivity, it.headerUrl, ivAvatar)
            tvNickname.setText("" + it.nickName)
            tvSign.text = it.introduce
            tvAge.text = it.birthday
            tvJob.text = it.career
            tvHeight.text = it.userHeight
            tvWeight.text = it.bodyWeight
            tvJyfw.text = it.findCity
        }
    }

    private fun initFemale() {
        // 微信
        layout_wechat.visibility = View.VISIBLE
        layout_wechat.findViewById<TextView>(R.id.label_start).text = "微信账号"
        etWechat = layout_wechat.findViewById(R.id.label_et)
        if (!TextUtils.isEmpty("")) {
            etWechat.setText("")
        } else {
            etWechat.hint = "填写微信号"
            etWechat.setText("")
        }

        // 身形
        layout_sx.visibility = View.VISIBLE
        layout_sx.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_SX.str
        tvSx = layout_sx.findViewById(R.id.label_tv)
        if (!TextUtils.isEmpty("")) {
            tvSx.text = ""
        } else {
            tvSx.text = "不详"
        }
        layout_sx.setOnClickListener(this)
    }

    private fun initMale() {
        // 交友节目
        layout_jyjm.visibility = View.VISIBLE
        layout_jyjm.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_JYJM.str
        tvJyjm = layout_jyjm.findViewById(R.id.label_tv)
        layout_jyjm.setOnClickListener(this)

        // 喜欢的女生特质
        layout_xhdnstz.visibility = View.VISIBLE
        layout_xhdnstz.findViewById<TextView>(R.id.label_start).text =
            UserProfile.SPECIAL_LIKE_FEMALE.str
        tvXhdnstz = layout_xhdnstz.findViewById(R.id.label_tv)
        layout_xhdnstz.setOnClickListener(this)

        initXhdnstzRcy()
    }

    private fun initGxbqRcy() {
        val recyclerView = layout_gxbq.findViewById<RecyclerView>(R.id.rv_basic)
        gxbqAdapter = ProfileLabelAdapter()
        val linearLayoutManager = LinearLayoutManager(this)
        linearLayoutManager.orientation = RecyclerView.HORIZONTAL
        recyclerView.visibility = View.VISIBLE
        recyclerView.layoutManager = linearLayoutManager
        recyclerView.adapter = gxbqAdapter
    }

    private fun initXhdnstzRcy() {
        val recyclerView = layout_xhdnstz.findViewById<RecyclerView>(R.id.rv_basic)
        xhdnstzAdapter = ProfileLabelAdapter()
        val linearLayoutManager = LinearLayoutManager(this)
        linearLayoutManager.orientation = RecyclerView.HORIZONTAL
        recyclerView.visibility = View.VISIBLE
        recyclerView.layoutManager = linearLayoutManager
        recyclerView.adapter = xhdnstzAdapter
    }

    private fun initView() {
        // 头像
        ivAvatar = layout_avatar.findViewById(R.id.iv_avatar)
        layout_avatar.findViewById<TextView>(R.id.label_tv).text = "点击修改头像"
        layout_avatar.findViewById<TextView>(R.id.label_tv).setTextColor(Color.WHITE)
        layout_avatar.setOnClickListener(this)

        // 昵称
        layout_nickname.findViewById<TextView>(R.id.label_start).text = "昵称"
        tvNickname = layout_nickname.findViewById(R.id.label_et)
        if (!TextUtils.isEmpty("")) {
            tvNickname.setText("")
        } else {
            tvNickname.hint = "填写昵称"
        }

        // 个性签名
        layout_gxqm.findViewById<TextView>(R.id.label_start).text = "个性签名"
        tvSign = layout_gxqm.findViewById(R.id.label_tv)
        if (!TextUtils.isEmpty("")) {
            tvSign.text = ""
        } else {
            tvSign.text = "不详"
        }
        layout_gxqm.setOnClickListener(this)

        // 年龄
        layout_nl.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_NL.str
        tvAge = layout_nl.findViewById(R.id.label_tv)
        if (!TextUtils.isEmpty("")) {
            tvAge.text = ""
        } else {
            tvAge.text = "不详"
        }
        layout_nl.setOnClickListener(this)

        // 职业
        layout_zy.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_ZY.str
        tvJob = layout_zy.findViewById(R.id.label_tv)
        if (!TextUtils.isEmpty("")) {
            tvJob.text = ""
        } else {
            tvJob.text = "不详"
        }
        layout_zy.setOnClickListener(this)

        // 身高
        layout_sg.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_SG.str
        tvHeight = layout_sg.findViewById(R.id.label_tv)
        if (!TextUtils.isEmpty("")) {
            tvHeight.text = ""
        } else {
            tvHeight.text = "不详"
        }
        layout_sg.setOnClickListener(this)

        // 体重
        layout_tz.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_TZ.str
        tvWeight = layout_tz.findViewById<TextView>(R.id.label_tv)
        if (!TextUtils.isEmpty("")) {
            tvWeight.text = ""
        } else {
            tvWeight.text = "不详"
        }
        layout_tz.setOnClickListener(this)

        // 交友范围
        layout_jyfw.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_JYFW.str
        tvJyfw = layout_jyfw.findViewById<TextView>(R.id.label_tv)
        if (!TextUtils.isEmpty("")) {
            tvJyfw.text = ""
        } else {
            tvJyfw.text = "不详"
        }
        layout_jyfw.setOnClickListener(this)

        // 个性标签
        layout_gxbq.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_GXBQ.str
        layout_gxbq.setOnClickListener(this)
        initGxbqRcy()
    }

    private fun getPickerData(pickerType: String): MutableList<PickBean> {
        val data = mutableListOf<PickBean>()

        val stringData = when (pickerType) {
            UserProfile.PROFILE_SG.str -> {
                UserProfile.PROFILE_SG.arr
            }
            UserProfile.PROFILE_TZ.str -> {
                UserProfile.PROFILE_TZ.arr
            }
            UserProfile.PROFILE_SX.str -> {
                UserProfile.PROFILE_SX.arr
            }
            UserProfile.PROFILE_JYFW.str -> {
                UserProfile.PROFILE_JYFW.arr
            }
            UserProfile.PROFILE_ZY.str -> {
                UserProfile.PROFILE_ZY.arr
            }
            UserProfile.PROFILE_JYJM.str -> {
                UserProfile.PROFILE_JYJM.arr
            }
            else -> {
                UserProfile.UNKNOWN.arr
            }
        }

        if (stringData != null) {
            for (stringDatum in stringData) {
                data.add(PickBean(stringDatum, false))
            }
        }

        return data
    }

    private fun showAddressDialog() {
        val provinceIndex = 0
        val cityIndex = 0

        // 弹出选择器
        val pvOptions =
            OptionsPickerBuilder(this) { options1, options2, _, v -> //返回的分别是三个级别的选中位置
                val opt1tx =
                    if (addressOptions1Items!!.isNotEmpty()) addressOptions1Items!![options1]
                        .pickerViewText else ""
                val opt2tx = if (addressOptions2Items!!.size > 0
                    && addressOptions2Items!![options1].size > 0
                ) addressOptions2Items!![options1][options2] else ""

                val tx = "$opt1tx-$opt2tx"
                userProfileData?.findCity = tx
                tvJyfw.text = tx
            }
                .setSelectOptions(provinceIndex, cityIndex)
                .setDividerColor(Color.BLACK)
                .setTextColorCenter(Color.BLACK) //设置选中项文字颜色
                .setContentTextSize(20)
                .build<Any>()

        pvOptions.setPicker(
            addressOptions1Items as List<Nothing>,
            addressOptions2Items as List<Nothing>
        )
        pvOptions.show()
    }

    private fun showJobPick() {
        val provinceIndex = 0
        val cityIndex = 0

        // 弹出选择器
        val pvOptions = OptionsPickerBuilder(this) { options1, options2, _, _ ->
            //返回的分别是三个级别的选中位置
            val opt1tx = if (jobOptions1Items!!.isNotEmpty()) jobOptions1Items!![options1]
                .pickerViewText else ""
            val opt2tx = if (jopOptions2Items!!.size > 0
                && jopOptions2Items!![options1].size > 0
            ) jopOptions2Items!![options1][options2] else ""

            val tx = "$opt1tx-$opt2tx"
            userProfileData?.career = tx
            tvJob.text = tx
        }
            .setSelectOptions(provinceIndex, cityIndex)
            .setDividerColor(Color.BLACK)
            .setTextColorCenter(Color.BLACK) //设置选中项文字颜色
            .setContentTextSize(20)
            .build<Any>()

        pvOptions.setPicker(
            jobOptions1Items as List<Nothing>,
            jopOptions2Items as List<Nothing>
        ) //三级选择器

        pvOptions.show()
    }

    private fun showPickDialog(pickerType: String, defaultValue: String?) {
        when (pickerType) {
            UserProfile.PROFILE_SG.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this, UserProfile.PROFILE_SG.str,
                    getPickerData(UserProfile.PROFILE_SG.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {
                        userProfileData?.userHeight = result
                        tvHeight.text = result
                    }
                })
                mSinglePickDialog?.show()
            }
            UserProfile.PROFILE_TZ.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_TZ.str,
                    getPickerData(UserProfile.PROFILE_TZ.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {
                        userProfileData?.bodyWeight = result
                        tvWeight.text = result
                    }
                })
                mSinglePickDialog?.show()
            }
            UserProfile.PROFILE_SX.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_SX.str,
                    getPickerData(UserProfile.PROFILE_SX.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {
                        userProfileData?.appearance = result
                        tvSx.text = result
                    }
                })
                mSinglePickDialog?.show()
            }
            UserProfile.PROFILE_JYJM.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_JYJM.str,
                    getPickerData(UserProfile.PROFILE_JYJM.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {
                        userProfileData?.interest = result
                        tvJyjm.text = result
                    }
                })
                mSinglePickDialog?.show()
            }
            UserProfile.PROFILE_ZY.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_ZY.str,
                    getPickerData(UserProfile.PROFILE_ZY.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {
                        userProfileData?.career = result
                        tvJob.text = result
                    }
                })
                mSinglePickDialog?.show()
            }
            else -> {}
        }
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.tv_save -> {
                // 保存资料
                userProfileData?.let { editProfilePresenter.setUserInfo(it) }
            }
            R.id.layout_xhdnstz -> {
                val bundle = Bundle()
                bundle.putBoolean(Constant.IS_LIKE_FEMALE_LABEL, true)
                readyGoForResult(
                    UserLabelActivity::class.java,
                    Constant.LIKE_FEMALE_LABEL_REQUEST_CODE,
                    bundle
                )
            }
            R.id.layout_avatar -> {
                showAlbum()
            }
            R.id.layout_gxqm -> {
                // 个性签名
                readyGoForResult(WriteSignatureActivity::class.java, Constant.EDIT_PROFILE_CODE)
            }
            R.id.layout_nl -> {
                showPickDialog(UserProfile.PROFILE_NL.str, userProfileData?.age)
            }
            R.id.layout_zy -> {
                showJobPick()
            }
            R.id.layout_sg -> {
                showPickDialog(UserProfile.PROFILE_SG.str, userProfileData?.userHeight)
            }
            R.id.layout_tz -> {
                showPickDialog(UserProfile.PROFILE_TZ.str, userProfileData?.bodyWeight)
            }
            R.id.layout_sx -> {
                showPickDialog(UserProfile.PROFILE_SX.str, userProfileData?.appearance)
            }
            R.id.layout_jyfw -> {
                showAddressDialog()
            }
            R.id.layout_jyjm -> {
                showPickDialog(UserProfile.PROFILE_JYJM.str, userProfileData?.findCity)
            }
            R.id.layout_gxbq -> {
                readyGoForResult(UserLabelActivity::class.java, Constant.USER_LABEL_REQUEST_CODE)
            }
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tv_save.setOnClickListener(this)
    }

    private fun showAlbum() {
        val windowAnimationStyle = PictureWindowAnimationStyle()
        windowAnimationStyle.ofAllAnimation(
            com.luck.picture.lib.R.anim.picture_anim_up_in,
            com.luck.picture.lib.R.anim.picture_anim_down_out
        )

        RxPermissions(this)
            .request(Manifest.permission.READ_EXTERNAL_STORAGE)
            .subscribe { granted: Boolean ->
                if (granted) {
                    val isEnableCrop = true
                    PictureSelector.create(this)
                        .openGallery(PictureMimeType.ofImage())
                        .theme(R.style.picture_WeChat_style) // 微信主题色
                        .isWeChatStyle(true) // 微信样式
                        .isCamera(true) //列表是否显示拍照按钮
                        .isZoomAnim(false)//图片选择缩放效果
                        .isEnableCrop(isEnableCrop)//是否开启裁剪
                        .setPictureWindowAnimationStyle(windowAnimationStyle)
                        .withAspectRatio(4, 4)
                        .isCompress(true)//是否压缩
                        .compressFocusAlpha(false)//压缩后是否保持图片的透明通道
                        .minimumCompressSize(200)// 小于多少kb的图片不压缩
                        .compressQuality(60)//图片压缩后输出质量
                        .synOrAsy(true)//开启同步or异步压缩
                        .maxSelectNum(10)
                        .setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_UNSPECIFIED)//屏幕旋转方向
                        .selectionMode(PictureConfig.SINGLE)//单选or多选
                        .imageEngine(GlideEngine.createGlideEngine())// 图片加载引擎
                        .forResult(PictureConfig.CHOOSE_REQUEST)
                } else {
                    showMissingPermissionDialog("存储")
                }
            }
    }

    /**
     * 鲁班压缩
     */
    private fun luban(cutPath: String) {
        val media = LocalMedia(cutPath, 0, false, 1, 0, PictureMimeType.ofImage())
        media.cutPath = cutPath
        if (SdkVersionUtils.checkedAndroid_Q()) {
            media.androidQToPath = cutPath
        }

        runOnUiThread {
            showLoading("加载中...")
        }

        val newFileName = DateUtils.getCreateFileName("IMG_CMP_") + ".jpeg"

        PictureThreadUtils.executeByIo(object : PictureThreadUtils.SimpleTask<List<File>>() {
            @Throws(Exception::class)
            override fun doInBackground(): List<File> {
                return Luban.with(mContext)
                    .loadMediaData<LocalMedia>(arrayListOf(media))
                    .ignoreBy(200)
                    .isCamera(false)
                    .setCompressQuality(80)
                    .setTargetDir(null)
                    .setFocusAlpha(false)
                    .setNewCompressFileName(newFileName).get()
            }

            override fun onSuccess(files: List<File>) {
                uploadOss(files[0].path, OssType.PHOTO.type)
            }

            override fun onFail(t: Throwable?) {
                super.onFail(t)
                hideLoading()
            }
        })
    }

    /**
     * 上传到oss服务器
     */
    private fun uploadOss(localFile: String, type: String) {
        OssManager.instance?.run {
            uploadImg(type, localFile)
            setOssUploadImgListener(object : OssManager.OssUploadImgListener {
                override fun uploadImgFailForSubthread(errorInfo: String) {
                    runOnUiThread {
                        showToast(errorInfo)
                    }
                }

                override fun uploadImgSuccessForSubthread(imgPath: String?) {
                    runOnUiThread {
                        if (TextUtils.isEmpty(imgPath)) {
                            showToast("图片异常，请重新添加")
                            return@runOnUiThread
                        }
                        avatarUrl = imgPath!!
                        GlideUtils.loadImageView(this@EditProfileActivity, avatarUrl, ivAvatar)
                    }
                }
            })
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        when (resultCode) {
            Activity.RESULT_OK -> {
                when (requestCode) {
                    // 相册获取图片
                    PictureConfig.CHOOSE_REQUEST -> {
                        val selectList: List<LocalMedia> =
                            PictureSelector.obtainMultipleResult(data)
                        val img = selectList[0]
                        uploadOss(img.compressPath, OssType.PHOTO.type)
                    }
                    // 裁剪获取图片
                    UcropUtils.UCROP_REQUEST_CODE -> {
                        data?.let {
                            val uri = UCrop.getOutput(it)
                            luban(uri?.path!!)
                        }
                    }
                }
            }
            UCrop.RESULT_ERROR -> {
                showToast("裁剪失败，请再试一下")
            }
            Constant.USER_LABEL_REQUEST_CODE -> {
                val sbLabel = data?.getStringExtra(Constant.USER_LABEL_DATA)
                userProfileData?.tagsCommon = sbLabel
                if (!TextUtils.isEmpty(userProfileData?.tagsCommon)) {
                    val tagsList =
                        gson.fromJson(userProfileData?.tagsCommon, Array<String>::class.java)
                    gxbqAdapter?.setNewInstance(tagsList.toCollection(ArrayList()))
                }
            }
            Constant.LIKE_FEMALE_LABEL_REQUEST_CODE -> {
                val sbLabel = data?.getStringExtra(Constant.USER_LABEL_DATA)
                userProfileData?.findDescribe = sbLabel
                if (!TextUtils.isEmpty(userProfileData?.findDescribe)) {
                    val tagsList =
                        gson.fromJson(userProfileData?.findDescribe, Array<String>::class.java)
                    xhdnstzAdapter?.setNewInstance(tagsList.toCollection(ArrayList()))
                }
            }
            Constant.EDIT_PROFILE_CODE -> {
                val signature = data?.getStringExtra(Constant.EDIT_PROFILE_SIGNATURE_STR)
                userProfileData?.introduce = signature
                tvSign.text = signature
            }
        }
    }

    override fun getUserInfoSuc(data: UserProfileDataInfo) {
        this.userProfileData = data.info
        initData()
    }

    override fun getUserInfoFail() {
    }

    override fun setUserInfoSuc() {
        showToast("资料保存成功！")
        finish()
    }

    override fun setUserInfoFail() {}
}
