package com.duben.roseplaylet.ui.activitys

import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.view.View
import android.view.WindowManager
import com.duben.roseplaylet.MintsApplication
import com.duben.roseplaylet.R
import com.duben.roseplaylet.utils.ToastUtil
import com.tencent.qcloud.tuikit.tuichat.bean.C2CChatInfo
import com.tencent.qcloud.tuikit.tuichat.bean.ChatInfo
import com.tencent.qcloud.tuikit.tuichat.classicui.page.TUIBaseChatActivity
import com.tencent.qcloud.tuikit.tuichat.classicui.page.TUIC2CChatFragment
import com.tencent.qcloud.tuikit.tuichat.presenter.C2CChatPresenter
import com.tencent.qcloud.tuikit.tuichat.util.TUIChatLog

/**
 *  @author Assen
 *  @date 2025/1/12
 *  @desc
 */
class IMActivity : TUIBaseChatActivity() {

    companion object {
        private val TAG = IMActivity::class.java.simpleName
    }

    private lateinit var chatFragment: TUIC2CChatFragment

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        // 状态栏黑底白字
        window.clearFlags(WindowManager.LayoutParams.FLAG_TRANSLUCENT_NAVIGATION)
        window.addFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS)
        window.statusBarColor = resources.getColor(R.color.color_171619)
        window.navigationBarColor = resources.getColor(R.color.color_171619)
        var vis = window.decorView.systemUiVisibility
        vis = vis or View.SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR
        window.decorView.systemUiVisibility = vis
    }

    override fun initChat(chatInfo: ChatInfo) {
        TUIChatLog.i(TAG, "inti chat $chatInfo")
        if (chatInfo !is C2CChatInfo) {
            TUIChatLog.e(TAG, "init C2C chat failed , chatInfo = $chatInfo")
            ToastUtil.show(MintsApplication.getContext(), "init c2c chat failed.")
            return
        }
        TUIChatLog.e(TAG, "init C2C chat failed , chatInfo_id = ${chatInfo.id}")
        chatFragment = TUIC2CChatFragment()
        chatFragment.chatInfo = chatInfo
        supportFragmentManager.beginTransaction()
            .replace(R.id.chat_fragment_container, chatFragment)
            .commitAllowingStateLoss()

        initChatSetting()
    }

    private fun initChatSetting() {
        Handler(Looper.getMainLooper()).postDelayed({
            val chatView = chatFragment.chatView

            chatView.viewline.visibility = View.GONE
//            chatView.inputView.setInterceptTouchEvent(true)
            chatView.inputView.setBgColor(resources.getColor(R.color.color_171619))
            chatView.inputView.setOnClickListener {

            }

            val titleBarLayout = chatView.titleBar
            titleBarLayout.setBgColor(resources.getColor(R.color.color_15141A))
            titleBarLayout.middleTitle.setTextColor(Color.WHITE)

            // titleBarLayout.setTitle("哈哈哈", ITitleBarLayout.Position.MIDDLE)
            titleBarLayout.setRightIcon(R.mipmap.ic_alipay)
            titleBarLayout.rightGroup.setOnClickListener {
                ToastUtil.show(MintsApplication.getContext(), "OOOOOOO")
            }
        }, 100)
    }

    override fun onDestroy() {
        val chatPresenter: C2CChatPresenter? = chatFragment.presenter
        chatPresenter?.removeC2CChatEventListener()
        super.onDestroy()
    }

    override fun getContentViewLayoutID(): Int {
        return R.layout.activity_im
    }
}