package com.duben.roseplaylet.ui.activitys

import android.Manifest
import android.app.Activity
import android.content.Intent
import android.content.pm.ActivityInfo
import android.graphics.Color
import android.text.TextUtils
import android.view.View
import android.widget.TextView
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.duben.library.utils.GlideUtils
import com.duben.roseplaylet.R
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.common.OssType
import com.duben.roseplaylet.common.UserProfile
import com.duben.roseplaylet.manager.FaceVerifyHelper
import com.duben.roseplaylet.manager.OssManager
import com.duben.roseplaylet.mvp.model.*
import com.duben.roseplaylet.mvp.presenters.RealAuthPresenter
import com.duben.roseplaylet.mvp.views.RealAuthView
import com.duben.roseplaylet.ui.adapter.ProfileLabelAdapter
import com.duben.roseplaylet.ui.widgets.pick.SinglePickDialog
import com.duben.roseplaylet.utils.GlideEngine
import com.google.gson.Gson
import com.luck.picture.lib.PictureSelector
import com.luck.picture.lib.compress.Luban
import com.luck.picture.lib.config.PictureConfig
import com.luck.picture.lib.config.PictureMimeType
import com.luck.picture.lib.entity.LocalMedia
import com.luck.picture.lib.style.PictureWindowAnimationStyle
import com.luck.picture.lib.thread.PictureThreadUtils
import com.luck.picture.lib.tools.DateUtils
import com.luck.picture.lib.tools.SdkVersionUtils
import com.tbruyelle.rxpermissions.RxPermissions
import com.yalantis.ucrop.UCrop
import kotlinx.android.synthetic.main.activity_real_auth.*
import kotlinx.android.synthetic.main.header_layout.*
import java.io.File

class RealAuthActivity : BaseActivity(), View.OnClickListener, RealAuthView {

    private val realAuthPresenter by lazy { RealAuthPresenter() }
    private val gson by lazy { Gson() }

    private lateinit var sgTv: TextView

    private lateinit var tzTv: TextView
    private lateinit var sxTv: TextView
    private lateinit var jyfwTv: TextView
    private lateinit var zyTv: TextView

    private var userProfileData: UserProfileData? = null
    private var gxbqAdapter: ProfileLabelAdapter? = null

    private var mStep = 1

    private var isWechatQrCodeUrl = false
    private var wechatQrCodeUrl = ""
    private var readAuthImageUrl = ""

    private var mSinglePickDialog: SinglePickDialog? = null

    override fun getContentViewLayoutID() = R.layout.activity_real_auth

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        realAuthPresenter.attachView(this)

        tv_title.text = "真人认证"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        line.visibility = View.GONE

        initProfile()
        initGxbqRcy()
        initListener()

        changeStepStatus(1)
    }

    private fun initGxbqRcy() {
        val recyclerView = layout_gxbq.findViewById<RecyclerView>(R.id.rv_basic)
        gxbqAdapter = ProfileLabelAdapter()
        val linearLayoutManager = LinearLayoutManager(this)
        linearLayoutManager.orientation = RecyclerView.HORIZONTAL
        recyclerView.visibility = View.VISIBLE
        recyclerView.layoutManager = linearLayoutManager
        recyclerView.adapter = gxbqAdapter
    }

    private fun initProfile() {
        // 身高
        layout_sg.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_SG.str
        sgTv = layout_sg.findViewById(R.id.label_tv)
        sxTv.text = "请选择您的身高"
        layout_sg.setOnClickListener(this)

        // 体重
        layout_tz.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_TZ.str
        tzTv = layout_tz.findViewById(R.id.label_tv)
        sxTv.text = "请选择您的体重"
        layout_tz.setOnClickListener(this)

        // 身形
        layout_sx.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_SX.str
        sxTv = layout_sx.findViewById(R.id.label_tv)
        sxTv.text = "请选择您的身型"
        layout_sx.setOnClickListener(this)

        // 交友范围
        layout_jyfw.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_JYFW.str
        jyfwTv = layout_jyfw.findViewById(R.id.label_tv)
        layout_jyfw.setOnClickListener(this)

        // 职业
        layout_zy.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_ZY.str
        zyTv = layout_zy.findViewById(R.id.label_tv)
        sxTv.text = "请选择您的职业"
        layout_zy.setOnClickListener(this)

        // 个性标签
        layout_gxbq.findViewById<TextView>(R.id.label_start).text = UserProfile.PROFILE_GXBQ.str
        layout_gxbq.setOnClickListener(this)
    }

    override fun onDestroy() {
        super.onDestroy()
        realAuthPresenter.detachView()
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.iv_next_step -> {
                doStep()
            }
            R.id.iv_auth -> {
                showAlbum()
            }
            R.id.iv_wechat_qrcode -> {
                showAlbum()
            }
            R.id.layout_sg -> {
                val defaultValue = if (TextUtils.isEmpty(userProfileData?.userHeight)) {
                    "170CM"
                } else {
                    userProfileData?.userHeight
                }
                showPickDialog(UserProfile.PROFILE_SG.str, defaultValue)
            }
            R.id.layout_tz -> {
                val defaultValue = if (TextUtils.isEmpty(userProfileData?.bodyWeight)) {
                    "50KG"
                } else {
                    userProfileData?.bodyWeight
                }
                showPickDialog(UserProfile.PROFILE_TZ.str, defaultValue)
            }
            R.id.layout_sx -> {
                showPickDialog(UserProfile.PROFILE_SX.str, userProfileData?.appearance)
            }
            R.id.layout_jyfw -> {
                showPickDialog(UserProfile.PROFILE_JYFW.str, userProfileData?.findCity)
            }
            R.id.layout_zy -> {
                showPickDialog(UserProfile.PROFILE_ZY.str, userProfileData?.career)
            }
            R.id.layout_gxbq -> {
                readyGoForResult(UserLabelActivity::class.java, Constant.USER_LABEL_REQUEST_CODE)
            }
        }
    }

    private fun changeStepStatus(step: Int) {
        mStep = step
        when (mStep) {
            1 -> {
                tv_step_1.setBackgroundResource(R.drawable.shape_orange_round)
                tv_step_2.setBackgroundResource(R.drawable.shape_gray_round)
                tv_step_3.setBackgroundResource(R.drawable.shape_gray_round)
                tv_step_4.setBackgroundResource(R.drawable.shape_gray_round)
                tv_step_1.setTextColor(Color.BLACK)
                tv_step_2.setTextColor(Color.WHITE)
                tv_step_3.setTextColor(Color.WHITE)
                tv_step_4.setTextColor(Color.WHITE)
                isWechatQrCodeUrl = false
                ll_step1.visibility = View.VISIBLE
                ll_step3.visibility = View.GONE
                ll_step4.visibility = View.GONE
            }
            2 -> {
            }
            3 -> {
                tv_step_1.setBackgroundResource(R.drawable.shape_orange_round)
                tv_step_2.setBackgroundResource(R.drawable.shape_orange_round)
                tv_step_3.setBackgroundResource(R.drawable.shape_orange_round)
                tv_step_4.setBackgroundResource(R.drawable.shape_gray_round)
                tv_step_1.setTextColor(Color.BLACK)
                tv_step_2.setTextColor(Color.BLACK)
                tv_step_3.setTextColor(Color.BLACK)
                tv_step_4.setTextColor(Color.WHITE)
                ll_step1.visibility = View.GONE
                ll_step3.visibility = View.VISIBLE
                ll_step4.visibility = View.GONE
            }
            4 -> {
                tv_step_1.setBackgroundResource(R.drawable.shape_orange_round)
                tv_step_2.setBackgroundResource(R.drawable.shape_orange_round)
                tv_step_3.setBackgroundResource(R.drawable.shape_orange_round)
                tv_step_4.setBackgroundResource(R.drawable.shape_orange_round)
                tv_step_1.setTextColor(Color.BLACK)
                tv_step_2.setTextColor(Color.BLACK)
                tv_step_3.setTextColor(Color.BLACK)
                tv_step_4.setTextColor(Color.BLACK)
                isWechatQrCodeUrl = true
                ll_step1.visibility = View.GONE
                ll_step3.visibility = View.GONE
                ll_step4.visibility = View.VISIBLE
            }
        }
    }

    private fun doStep() {
        when (mStep) {
            1 -> {
                if (TextUtils.isEmpty(readAuthImageUrl)) {
                    showToast("请先上传本人照片")
                } else {
                    luban(readAuthImageUrl)
                }
            }
            2 -> {}
            3 -> {
                // 校验是否未选
                if (TextUtils.isEmpty(userProfileData?.userHeight)) {
                    showToast("请选择您的身高")
                    return
                }
                if (TextUtils.isEmpty(userProfileData?.bodyWeight)) {
                    showToast("请选择您的体重")
                    return
                }
                if (TextUtils.isEmpty(userProfileData?.appearance)) {
                    showToast("请选择您的身型")
                    return
                }
                if (TextUtils.isEmpty(userProfileData?.findCity)) {
                    showToast("请选择您的交友范围")
                    return
                }
                if (TextUtils.isEmpty(userProfileData?.career)) {
                    showToast("请选择您的职业")
                    return
                }
                if (TextUtils.isEmpty(userProfileData?.tagsCommon)) {
                    showToast("请选择您的个性标签")
                    return
                }
                realAuthPresenter.getUserInfo()
            }
            4 -> {
                if (TextUtils.isEmpty(wechatQrCodeUrl)) {
                    showToast("请先上传微信二维码")
                } else {
                    luban(wechatQrCodeUrl)
                }
            }
            else -> {}
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        iv_next_step.setOnClickListener(this)
        iv_auth.setOnClickListener(this)
        iv_wechat_qrcode.setOnClickListener(this)
    }

    private fun showPickDialog(pickerType: String, defaultValue: String?) {
        when (pickerType) {
            UserProfile.PROFILE_SG.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_SG.str,
                    getPickerData(UserProfile.PROFILE_SG.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {

                    }
                })
                mSinglePickDialog?.show()
            }
            UserProfile.PROFILE_TZ.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_TZ.str,
                    getPickerData(UserProfile.PROFILE_TZ.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {

                    }
                })
                mSinglePickDialog?.show()
            }
            UserProfile.PROFILE_SX.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_SX.str,
                    getPickerData(UserProfile.PROFILE_SX.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {

                    }
                })
                mSinglePickDialog?.show()
            }
            UserProfile.PROFILE_JYFW.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_JYFW.str,
                    getPickerData(UserProfile.PROFILE_JYFW.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {

                    }
                })
                mSinglePickDialog?.show()
            }
            UserProfile.PROFILE_ZY.str -> {
                mSinglePickDialog = SinglePickDialog(
                    this,
                    UserProfile.PROFILE_ZY.str,
                    getPickerData(UserProfile.PROFILE_ZY.str),
                    defaultValue
                )
                mSinglePickDialog?.setPickResultListener(object :
                    SinglePickDialog.OnPickResultListener {
                    override fun onPickResult(result: String) {

                    }
                })
                mSinglePickDialog?.show()
            }
            else -> {}
        }
    }

    private fun getPickerData(pickerType: String): MutableList<PickBean> {
        val data = mutableListOf<PickBean>()

        val stringData = when (pickerType) {
            UserProfile.PROFILE_SG.str -> {
                UserProfile.PROFILE_SG.arr
            }
            UserProfile.PROFILE_TZ.str -> {
                UserProfile.PROFILE_TZ.arr
            }
            UserProfile.PROFILE_SX.str -> {
                UserProfile.PROFILE_SX.arr
            }
            UserProfile.PROFILE_JYFW.str -> {
                UserProfile.PROFILE_JYFW.arr
            }
            UserProfile.PROFILE_ZY.str -> {
                UserProfile.PROFILE_ZY.arr
            }
            else -> {
                UserProfile.UNKNOWN.arr
            }
        }

        if (stringData != null) {
            for (stringDatum in stringData) {
                data.add(PickBean(stringDatum, false))
            }
        }

        return data
    }

    override fun getFaceParamSuc(data: FaceParam) {
        FaceVerifyHelper.instance.openCloudFaceService(this, data,
            object : FaceVerifyHelper.FaceVerifyCallback {
                override fun onFaceVerifyOver(result: FaceResult) {
                    if (result.isSuccess) {
                        changeStepStatus(3)
                    }
                    realAuthPresenter.faceResult(result)
                }
            })
    }

    override fun getFaceParamFail() {}

    override fun faceResultSuc() {
    }

    override fun faceResultFail() {}

    override fun getUserInfoSuc(data: UserProfileDataInfo) {
        this.userProfileData = data.info
        initData()
    }

    private fun initData() {

    }

    override fun getUserInfoFail() {
    }

    override fun setUserInfoSuc() {
    }

    override fun setUserInfoFail() {
    }

    private fun showAlbum() {
        val windowAnimationStyle = PictureWindowAnimationStyle()
        windowAnimationStyle.ofAllAnimation(
            com.luck.picture.lib.R.anim.picture_anim_up_in,
            com.luck.picture.lib.R.anim.picture_anim_down_out
        )

        RxPermissions(this)
            .request(Manifest.permission.READ_EXTERNAL_STORAGE)
            .subscribe { granted: Boolean ->
                if (granted) {
                    PictureSelector.create(this)
                        .openGallery(PictureMimeType.ofImage())
                        .theme(R.style.picture_WeChat_style) // 微信主题色
                        .isWeChatStyle(true) // 微信样式
                        .isCamera(true) //列表是否显示拍照按钮
                        .isZoomAnim(true)//图片选择缩放效果
                        .isEnableCrop(true)//是否开启裁剪
                        .setPictureWindowAnimationStyle(windowAnimationStyle)
                        .withAspectRatio(4, 4)
                        .isCompress(true)//是否压缩
                        .compressFocusAlpha(false)//压缩后是否保持图片的透明通道
                        .minimumCompressSize(200)// 小于多少kb的图片不压缩
                        .compressQuality(60)//图片压缩后输出质量
                        .synOrAsy(true)//开启同步or异步压缩
                        .maxSelectNum(1)
                        .setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_UNSPECIFIED)//屏幕旋转方向
                        .selectionMode(PictureConfig.SINGLE)//单选or多选
                        .imageEngine(GlideEngine.createGlideEngine())// 图片加载引擎
                        .forResult(PictureConfig.CHOOSE_REQUEST)
                } else {
                    showMissingPermissionDialog("存储")
                }
            }
    }

    /**
     * 鲁班压缩
     */
    private fun luban(cutPath: String) {
        val media = LocalMedia(cutPath, 0, false, 1, 0, PictureMimeType.ofImage())
        media.cutPath = cutPath
        if (SdkVersionUtils.checkedAndroid_Q()) {
            media.androidQToPath = cutPath
        }

        runOnUiThread {
            showLoading("加载中...")
        }

        val newFileName = DateUtils.getCreateFileName("IMG_CMP_") + ".jpeg"

        PictureThreadUtils.executeByIo(object : PictureThreadUtils.SimpleTask<List<File>>() {
            @Throws(Exception::class)
            override fun doInBackground(): List<File> {
                return Luban.with(mContext)
                    .loadMediaData<LocalMedia>(arrayListOf(media))
                    .ignoreBy(200)
                    .isCamera(false)
                    .setCompressQuality(80)
                    .setTargetDir(null)
                    .setFocusAlpha(false)
                    .setNewCompressFileName(newFileName).get()
            }

            override fun onSuccess(files: List<File>) {
                uploadOss(files[0].path, OssType.PHOTO.type)
            }

            override fun onFail(t: Throwable?) {
                super.onFail(t)
                hideLoading()
            }
        })
    }

    /**
     * 上传到oss服务器
     */
    private fun uploadOss(localFile: String, type: String) {
        OssManager.instance?.run {
            uploadImg(type, localFile)
            setOssUploadImgListener(object : OssManager.OssUploadImgListener {
                override fun uploadImgFailForSubthread(errorInfo: String) {
                    runOnUiThread {
                        showToast(errorInfo)
                    }
                }

                override fun uploadImgSuccessForSubthread(imgPath: String?) {
                    runOnUiThread {
                        if (TextUtils.isEmpty(imgPath)) {
                            showToast("图片异常，请重新添加")
                            return@runOnUiThread
                        }
                        if (isWechatQrCodeUrl) {
                            wechatQrCodeUrl = imgPath!!
//                            realAuthPresenter.faceResult()

                        } else {
                            readAuthImageUrl = imgPath!!
                            realAuthPresenter.getFaceParam(readAuthImageUrl)
                        }
                    }
                }
            })
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (resultCode == Activity.RESULT_OK) {
            when (requestCode) {
                // 相册获取图片
                PictureConfig.CHOOSE_REQUEST -> {
                    val selectList: List<LocalMedia> =
                        PictureSelector.obtainMultipleResult(data)
                    val img = selectList[0]

                    if (isWechatQrCodeUrl) {
                        wechatQrCodeUrl = img.compressPath
                        GlideUtils.loadImageViewNoAnim2(
                            this@RealAuthActivity,
                            wechatQrCodeUrl,
                            iv_wechat_qrcode
                        )
                    } else {
                        readAuthImageUrl = img.compressPath
                        GlideUtils.loadImageViewNoAnim2(
                            this@RealAuthActivity,
                            readAuthImageUrl,
                            iv_auth
                        )
                    }
                }
            }
        } else if (resultCode == UCrop.RESULT_ERROR) {
            showToast("裁剪失败，请再试一下")
        } else if (resultCode == Constant.USER_LABEL_REQUEST_CODE) {
            val sbLabel = data?.getStringExtra(Constant.USER_LABEL_DATA)
            userProfileData?.tagsCommon = sbLabel
            if (!TextUtils.isEmpty(userProfileData?.tagsCommon)) {
                val tagsList =
                    gson.fromJson(userProfileData?.tagsCommon, Array<String>::class.java)
                gxbqAdapter?.setNewInstance(tagsList.toCollection(ArrayList()))
            }
        }
    }

}
