package com.duben.roseplaylet.ui.activitys

import android.graphics.Color
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import com.duben.roseplaylet.R
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.manager.UserManager
import com.duben.roseplaylet.mvp.model.ShareRankList
import com.duben.roseplaylet.mvp.presenters.InvitePresenter
import com.duben.roseplaylet.mvp.views.InviteView
import com.duben.roseplaylet.ui.adapter.ShareInviteAdapter
import com.duben.roseplaylet.ui.adapter.ShareRankAdapter
import com.duben.roseplaylet.ui.widgets.ShareDialog
import com.duben.roseplaylet.utils.SpanUtils
import com.duben.roseplaylet.utils.UcropUtils
import kotlinx.android.synthetic.main.activity_share.*
import kotlinx.android.synthetic.main.header_layout.*

class ShareActivity : BaseActivity(), View.OnClickListener, InviteView {

    private var myShareUrl = ""

    private val userManager by lazy { UserManager.getInstance() }

    private val invitePresenter by lazy { InvitePresenter() }

    private lateinit var mShareRankAdapter: ShareRankAdapter
    private lateinit var mShareInviteAdapter: ShareInviteAdapter

    override fun getContentViewLayoutID() = R.layout.activity_share

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        invitePresenter.attachView(this)

        tv_title.text = "分享有奖"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        line.visibility = View.GONE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)

        invitePresenter.getSharePageMsg()
        invitePresenter.getShareOrders()
        invitePresenter.getShareUrl()
        invitePresenter.getRuserShareCode()

        initView()

        initListener()
    }

    private fun initView() {
        tv_my_code.text = userManager.shareCode


//        rcy_my_invite.adapter =

//        tv_share_cash.text = SpanUtils()
//            .append()
//            .create()

        mShareRankAdapter = ShareRankAdapter()
        mShareRankAdapter.animationEnable = false
        val emptyView = LayoutInflater.from(this).inflate(R.layout.item_empty_data, null)
        mShareRankAdapter.setEmptyView(emptyView)
        rcy_invite_top.adapter = mShareRankAdapter

        mShareInviteAdapter = ShareInviteAdapter()
        mShareInviteAdapter.animationEnable = false
        val emptyView2 = LayoutInflater.from(this).inflate(R.layout.item_empty_data, null)
        mShareInviteAdapter.setEmptyView(emptyView2)
        rcy_my_invite.adapter = mShareInviteAdapter
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.tv_copy -> {
                showToast("邀请码已复制到剪切板!")
                UcropUtils.clipData(userManager.shareCode)
            }
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tv_copy.setOnClickListener(this)
    }

    /**
     * 图片分享
     */
    private fun shareImgDialog() {
        val shareDialog = ShareDialog(this, myShareUrl)
        shareDialog.setOnShareOKListener(object : ShareDialog.OnShareOKListener {
            override fun onShareOk() {
            }
        })
        val content = "送你一个赚钱的新模式，\r\n快点加入跟我一起赚钱吧"
        shareDialog.setShareAvatar("https://mints-pkg.oss-cn-beijing.aliyuncs.com/pkg/img/ic_my_coin.png")
        shareDialog.setShareTitle("Hi,我是用户" + userManager.name)
        shareDialog.setShareContent(content)
        shareDialog.show()
    }

    override fun onDestroy() {
        super.onDestroy()
        invitePresenter.detachView()
    }

    override fun getSharePageMsgSuc(
        shareCode: String, rUserShareCode: String?,
    ) {
        tv_my_code.text = shareCode
        if (TextUtils.isEmpty(rUserShareCode)) {
            et_code.isEnabled = true
        } else {
            et_code.isEnabled = false
            et_code.setText(rUserShareCode!!)
        }

    }

    override fun getSharePageMsgFail() {

    }

    override fun getShareOrderSuc(data: ShareRankList) {
        mShareRankAdapter.setNewInstance(data.list)
    }

    override fun getShareOrderFail() {
    }

    override fun getShareUrlSuc(url: String) {
        myShareUrl = url
    }

    override fun getShareUrlSucFail() {

    }

    override fun getRuserShareCodeSuc(data: Any) {

    }

    override fun getRuserShareCodeSucFail() {
    }
}
