package com.duben.roseplaylet.ui.activitys

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.view.View
import androidx.core.content.ContextCompat
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.common.UserProfile
import com.duben.roseplaylet.manager.UserManager
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.roseplaylet.ui.adapter.FlowTagAdapter
import com.duben.roseplaylet.utils.SpanUtils
import com.google.gson.Gson
import kotlinx.android.synthetic.main.activity_user_label.*
import kotlinx.android.synthetic.main.header_layout.*

class UserLabelActivity : BaseActivity(), View.OnClickListener {

    private val gson by lazy { Gson() }

    private var userSex = UserManager.getInstance().userSex

    companion object {
        const val MAX_SELECT_COUNT = 6
    }

    private var isLikeFemale = false

    private var selectCount = 0
    private val usualData = arrayListOf<String>()
    private val specialData = arrayListOf<String>()

    private val likeData = arrayListOf<String>()

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            isLikeFemale = it.getBoolean(Constant.IS_LIKE_FEMALE_LABEL, false)
        }
    }

    override fun getContentViewLayoutID() = R.layout.activity_user_label

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        tv_right.visibility = View.VISIBLE
        tv_right.text = "确定"
        tv_title.setTextColor(Color.WHITE)
        tv_right.setTextColor(ContextCompat.getColor(this, R.color.color_E8CF83))
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)

        if (isLikeFemale) {
            // 喜欢的女生特质
            tv_title.text = UserProfile.SPECIAL_LIKE_FEMALE.str
            tv_label1.visibility = View.GONE
            tv_label2.visibility = View.GONE

            UserProfile.SPECIAL_LIKE_FEMALE.arr?.let {
                likeData.addAll(it)
            }

            val likeAdapter = FlowTagAdapter(this, likeData)
            flowlayout_usual.adapter = likeAdapter

            flowlayout_usual.setOnTagClickListener { _, _, _ ->
                updateData()
                false
            }
        } else {
            tv_title.text = "个性标签"

            if (userSex == 1) {
                initMale()
            } else {
                initFeMale()
            }

            val usualAdapter = FlowTagAdapter(this, usualData)
            flowlayout_usual.adapter = usualAdapter

            val specialAdapter = FlowTagAdapter(this, specialData)
            flowlayout_special.adapter = specialAdapter

            flowlayout_usual.setOnTagClickListener { _, _, _ ->
                updateData()
                false
            }

            flowlayout_special.setOnTagClickListener { _, _, _ ->
                updateData()
                false
            }
        }

        tv_select.text =
            SpanUtils()
                .append("已选择")
                .append("${selectCount}/${MAX_SELECT_COUNT}")
                .setForegroundColor(ContextCompat.getColor(this, R.color.color_E8CF83))
                .create()

        initListener()
    }

    private fun initFeMale() {
        tv_label1.text = UserProfile.USUAL_LABEL_FEMALE.str
        tv_label2.text = UserProfile.SPECIAL_LABEL_FEMALE.str

        UserProfile.USUAL_LABEL_FEMALE.arr?.let {
            usualData.addAll(it)
        }
        UserProfile.SPECIAL_LABEL_FEMALE.arr?.let {
            specialData.addAll(it)
        }
    }

    private fun initMale() {
        tv_label1.text = UserProfile.USUAL_LABEL_MALE.str
        tv_label2.text = UserProfile.SPECIAL_LABEL_MALE.str

        UserProfile.USUAL_LABEL_MALE.arr?.let {
            usualData.addAll(it)
        }
        UserProfile.SPECIAL_LABEL_MALE.arr?.let {
            specialData.addAll(it)
        }
    }

    private fun updateData() {
        selectCount = flowlayout_usual.selectedList.size + flowlayout_special.selectedList.size

        if (MAX_SELECT_COUNT - flowlayout_usual.selectedList.size <= 0) {
            flowlayout_usual.setMaxSelectCount(MAX_SELECT_COUNT)
            fl_special.setIntercepting(true)
        } else if (MAX_SELECT_COUNT - flowlayout_special.selectedList.size <= 0) {
            flowlayout_special.setMaxSelectCount(MAX_SELECT_COUNT)
            fl_usual.setIntercepting(true)
        } else if ((MAX_SELECT_COUNT - flowlayout_usual.selectedList.size - flowlayout_special.selectedList.size) <= 0) {
            fl_usual.setIntercepting(false)
            fl_special.setIntercepting(false)
            flowlayout_usual.setMaxSelectCount(flowlayout_usual.selectedList.size)
            flowlayout_special.setMaxSelectCount(flowlayout_special.selectedList.size)
        } else {
            fl_usual.setIntercepting(false)
            fl_special.setIntercepting(false)

            if (flowlayout_usual.selectedList.size > 0 && flowlayout_special.selectedList.size > 0) {
                flowlayout_usual.setMaxSelectCount(MAX_SELECT_COUNT - flowlayout_special.selectedList.size)
                flowlayout_special.setMaxSelectCount(MAX_SELECT_COUNT - flowlayout_usual.selectedList.size)
            } else if (flowlayout_usual.selectedList.size > 0 && flowlayout_special.selectedList.size <= 0) {
                flowlayout_usual.setMaxSelectCount(MAX_SELECT_COUNT)
                flowlayout_special.setMaxSelectCount(MAX_SELECT_COUNT - flowlayout_usual.selectedList.size)
            } else if (flowlayout_special.selectedList.size > 0 && flowlayout_usual.selectedList.size <= 0) {
                flowlayout_special.setMaxSelectCount(MAX_SELECT_COUNT)
                flowlayout_usual.setMaxSelectCount(MAX_SELECT_COUNT - flowlayout_special.selectedList.size)
            }
        }
        tv_select.text =
            SpanUtils()
                .append("已选择")
                .append("${selectCount}/${MAX_SELECT_COUNT}")
                .setForegroundColor(ContextCompat.getColor(this, R.color.color_E8CF83))
                .create()
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.tv_right -> {
                val labelData = arrayListOf<String>()

                if (!isLikeFemale) {
                    for (i in 0 until usualData.size) {
                        for (j in flowlayout_usual.selectedList) {
                            if (i == j) {
                                labelData.add(usualData[i])
                            }
                        }
                    }
                    for (i in 0 until specialData.size) {
                        for (j in flowlayout_special.selectedList) {
                            if (i == j) {
                                labelData.add(specialData[i])
                            }
                        }
                    }
                } else {
                    for (i in 0 until likeData.size) {
                        for (j in flowlayout_usual.selectedList) {
                            if (i == j) {
                                labelData.add(likeData[i])
                            }
                        }
                    }
                }

                val resultIntent = Intent()
                resultIntent.putExtra(Constant.USER_LABEL_DATA, gson.toJson(labelData))
                if (isLikeFemale) {
                    setResult(Constant.LIKE_FEMALE_LABEL_REQUEST_CODE, resultIntent)
                } else {
                    setResult(Constant.USER_LABEL_REQUEST_CODE, resultIntent)
                }
                finish()
            }
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tv_right.setOnClickListener(this)
    }
}
