package com.duben.roseplaylet.ui.activitys

import android.app.Dialog
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.TextUtils
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import com.airbnb.lottie.LottieAnimationView
import com.airbnb.lottie.LottieComposition
import com.airbnb.lottie.LottieCompositionFactory
import com.airbnb.lottie.LottieDrawable
import com.duben.library.utils.GlideUtils
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.MintsApplication
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.manager.IMHelper
import com.duben.roseplaylet.manager.UserHelper
import com.duben.roseplaylet.manager.UserManager
import com.duben.roseplaylet.mvp.model.SeeWechat
import com.duben.roseplaylet.mvp.model.UserProfileData
import com.duben.roseplaylet.mvp.presenters.UserProfilePresenter
import com.duben.roseplaylet.mvp.views.UserProfileView
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.roseplaylet.ui.adapter.UserProfileAlbumAdapter
import com.duben.roseplaylet.ui.adapter.base.OnItemClickListener
import com.duben.roseplaylet.ui.preview.ImagePreviewActivity
import com.duben.roseplaylet.ui.widgets.*
import com.duben.roseplaylet.utils.LogUtil
import com.duben.roseplaylet.utils.ToastUtil
import com.duben.roseplaylet.utils.UcropUtils
import com.google.android.material.appbar.AppBarLayout
import com.google.gson.Gson
import kotlinx.android.synthetic.main.activity_user_profile.*
import kotlinx.android.synthetic.main.layout_user_profile_case.*
import kotlinx.android.synthetic.main.layout_user_profile_head.*
import net.center.blurview.ShapeBlurView
import net.center.blurview.enu.BlurMode
import kotlin.math.abs

/**
 * 描述：用户信息
 */
class UserProfileActivity : BaseActivity(), View.OnClickListener, UserProfileView {

    private var albumData: ArrayList<String> = arrayListOf()
    private var userProfileAlbumAdapter: UserProfileAlbumAdapter? = null

    private var toUid = ""

    private var userIsMale = true

    private val userProfilePresenter by lazy { UserProfilePresenter() }
    private val gson by lazy { Gson() }

    private var userProfileData: UserProfileData? = null

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            toUid = it.getString(Constant.TO_UID, "")
        }
    }

    override fun getContentViewLayoutID() = R.layout.activity_user_profile

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        userProfilePresenter.attachView(this)

        initAppBar()
        initAlbumRcy()
        initListener()
    }

    override fun onResume() {
        super.onResume()
        userProfilePresenter.getMorePage(toUid)
    }

    private fun initView() {
        if (userIsMale) {
            // 男性
            view_male.visibility = View.VISIBLE
            tv_like_male.visibility = View.VISIBLE
            tv_wechat.visibility = View.GONE
            rl_top_female.visibility = View.GONE
            fl_head_male.visibility = View.VISIBLE
            tv_days.visibility = View.VISIBLE
            ll_impression.visibility = View.GONE
            tv_info_7.visibility = View.VISIBLE
        } else {
            // 女性
            view_male.visibility = View.GONE
            tv_like_male.visibility = View.GONE
            tv_wechat.visibility = View.VISIBLE
            rl_top_female.visibility = View.VISIBLE
            fl_head_male.visibility = View.GONE
            tv_days.visibility = View.GONE
            ll_impression.visibility = View.VISIBLE
            tv_info_5.visibility = View.VISIBLE
        }
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_head_back -> finish()
            R.id.iv_head_share -> {

            }
            R.id.iv_head_more -> {
                showToBlackDialog()
            }
            R.id.iv_like, R.id.tv_like_male -> {
                userProfileData?.let {
                    var toLikeStatus = 0
                    if (it.likeStatus == 0) {
                        toLikeStatus = 1
                    }
                    userProfilePresenter.toLike("" + it.uid, toLikeStatus)
                }
            }
            R.id.tv_chat -> {
                userProfileData?.let {
                    if (it.canChat) {
                        // 直接聊
                        IMHelper.instance.startChatActivity("" + it.uid)
                        return
                    }
                    // 自己是不是男性
                    if (UserManager.getInstance().userSex == 1) {
                        // 男性 非VIP 弹解锁聊天弹框
                        showUnlockChatDialog()
                    } else {
                        // 女性 弹出认证弹框
                        UserHelper.instance.showRealAuthDialog()
                    }
                }
            }
            R.id.tv_wechat -> {
                userProfilePresenter.seeWechat(toUid)
            }
        }
    }

    private fun initListener() {
        iv_head_back.setOnClickListener(this)
        iv_head_share.setOnClickListener(this)
        iv_head_more.setOnClickListener(this)
        tv_wechat.setOnClickListener(this)
        tv_chat.setOnClickListener(this)
        tv_like_male.setOnClickListener(this)
        iv_like.setOnClickListener(this)
    }

    override fun getMorePageSuc(data: UserProfileData) {
        this.userProfileData = data
        userIsMale = data.sex == 1
        initView()
        initData()
    }

    private fun initData() {
        userProfileData?.let {
            if (!UserManager.getInstance().vipFlag) {
                if (it.canSeeSurCount <= 0) {
                    // 设置模糊
                    setViewBlur()
                } else {
                    blurview.visibility = View.GONE
                }

                // 只要不是VIP 就弹解锁资料
                showProfileCountDialog(it.canSeeSurCount)
            }

            if (!TextUtils.isEmpty(it.images)) {
                albumData.clear()
                val array: Array<String> = gson.fromJson(it.images, Array<String>::class.java)
                array.forEach { it2 ->
                    albumData.add(it2)
                }
                userProfileAlbumAdapter?.notifyDataSetChanged()
            }

            if (userIsMale) {
                // 男性
                tv_days.text = "已注册" + it.days
                GlideUtils.loadImageView(this, it.headerUrl, iv_avatar_male)
                if (TextUtils.isEmpty(it.introduce)) {
                    tv_introduce_text.text = "小姐姐你好呀！"
                } else {
                    tv_introduce_text.text = it.introduce
                }
                // 喜欢女生特质
                if (!TextUtils.isEmpty(it.findDescribe)) {
                    tv_info_7.text = it.findDescribe
                } else {
                    tv_info_7.text = "秘密"
                }

                if (it.online) {
                    tv_online_male.visibility = View.VISIBLE
                } else {
                    tv_online_male.visibility = View.GONE
                }

            } else {
                GlideUtils.loadImageView(this, it.headerUrl, iv_avatar_female)
                if (TextUtils.isEmpty(it.introduce)) {
                    tv_introduce_text.text = "不知道写什么耶，哥哥帮我想想～"
                } else {
                    tv_introduce_text.text = it.introduce
                }
                tv_active.text = it.hallTime

                // 身型
                if (!TextUtils.isEmpty(it.appearance)) {
                    tv_info_5.text = it.appearance
                } else {
                    tv_info_5.text = "秘密"
                }

                if (it.idcardStatus == 1) {
                    tv_label_auth.visibility = View.VISIBLE
                }
            }

            tv_head_title.text = it.nickName
            GlideUtils.loadImageView(this, it.headerUrl, iv_head_avatar)

            if (it.likeStatus == 0) {
                playCancelCollectAnim(iv_like)
            } else {
                playCollectAnim(iv_like)
            }

            tv_label_name.text = it.nickName
            tv_like_count.text = "" + it.likeCount + "人喜欢"

            if (!TextUtils.isEmpty(it.age)) {
                tv_label_age.visibility = View.VISIBLE
                tv_label_age.text = "" + it.age + "岁"
            }

            if (!TextUtils.isEmpty(it.findCity)) {
                tv_label_address.visibility = View.VISIBLE
                tv_label_address.text = it.findCity
            }

            if (!TextUtils.isEmpty(it.distance)) {
                tv_label_distance.visibility = View.VISIBLE
                tv_label_distance.text = it.distance + "km"
            }

            tv_info_1.visibility = View.GONE

            // 身高
            if (!TextUtils.isEmpty(it.userHeight)) {
                tv_info_2.text = it.userHeight
            } else {
                tv_info_2.text = "秘密"
            }
            // 体重
            if (!TextUtils.isEmpty(it.bodyWeight)) {
                tv_info_3.text = it.bodyWeight
            } else {
                tv_info_3.text = "秘密"
            }
            // 城市
            if (!TextUtils.isEmpty(it.findCity)) {
                tv_info_4.text = it.findCity
            } else {
                tv_info_4.text = "秘密"
            }
            // 个性标签
            if (!TextUtils.isEmpty(it.tagsCommon)) {
                tv_info_6.text = it.tagsCommon
            } else {
                tv_info_6.text = "秘密"
            }

            // 工作
            if (!TextUtils.isEmpty(it.career)) {
                tv_info_8.text = it.career
            } else {
                tv_info_8.text = "秘密"
            }
        }
    }

    private fun initAlbumRcy() {
        userProfileAlbumAdapter = UserProfileAlbumAdapter(this, albumData)
        userProfileAlbumAdapter?.showAuth(userProfileData?.idcardStatus == 1)
        userProfileAlbumAdapter?.setOnItemClickListener(object : OnItemClickListener {
            override fun onItemClick(view: View?, position: Int) {
                userProfileAlbumAdapter?.let {
                    if (it.images.size <= 1) return
                    val preData = arrayListOf<String>()
                    for (image in it.images) {
                        preData.add(image)
                    }
                    val bundle = Bundle()
                    bundle.putStringArrayList(ImagePreviewActivity.IMAGE_PREVIEW_DATA, preData)
                    bundle.putInt(ImagePreviewActivity.IMAGE_PREVIEW_POSITION, position)
                    readyGo(ImagePreviewActivity::class.java, bundle)
                }
            }
        })
        val layoutManager = LinearLayoutManager(context)
        layoutManager.orientation = LinearLayoutManager.HORIZONTAL
        rcy_profile_album.layoutManager = layoutManager
        rcy_profile_album.adapter = userProfileAlbumAdapter
    }

    override fun getMorePageFail() {
    }

    override fun seeWechatSuc(data: SeeWechat) {
        if (data.canSee) {
            if (!data.hasWechat) {
                // 没有微信号
                showToast(data.errMsg)
            } else {
                // 直接看微信
                showSeeWechatDialog(data.wechat)
            }
        } else {
            // 弹解锁微信
            showUnlockWechatDialog()
        }
    }

    override fun seeWechatFail() {
    }

    override fun unlockInfoByCoinSuc() {
        // 解锁金币资料后刷新页面
//        userProfilePresenter.getMorePage(toUid)
    }

    override fun unlockWechatSuc() {
    }

    override fun unlockWechatFail() {
    }

    override fun toWhiteSuc() {
        showToast("已将对方移出黑名单！")
        userProfileData?.black = 0
    }

    override fun toBlackSuc() {
        showToast("拉黑成功！")
        userProfileData?.black = 1
    }

    override fun toLikeSuc(status: Int) {
        if (status == 0) {
            playCancelCollectAnim(iv_like)
        } else {
            playCollectAnim(iv_like)
        }
    }

    override fun onDestroy() {
        userProfilePresenter.detachView()
        super.onDestroy()
    }

    private fun showSeeWechatDialog(wechatCode: String) {
        userProfileData?.let {
            SeeWechatDialog(this,
                it.headerUrl,
                it.nickName,
                wechatCode,
                object : DialogListener() {
                    override fun onClick(dialog: Dialog?, v: View?) {
                        super.onClick(dialog, v)
                        dialog?.dismiss()
                        when (v?.id) {
                            R.id.tv_send_btn -> {
                                //
                            }
                            R.id.tv_copy -> {
                                ToastUtil.show(MintsApplication.getContext(), "微信已复制到剪切板!")
                                UcropUtils.clipData(wechatCode)
                            }
                        }
                    }
                }).show()
        }
    }

    private fun showUnlockChatDialog() {
        userProfileData?.let {
            UnlockChatDialog(this, it.headerUrl, object : DialogListener() {
                override fun onClick(dialog: Dialog?, v: View?) {
                    super.onClick(dialog, v)
                    //                dialog?.dismiss()
                    when (v?.id) {
                        R.id.tv_vip_btn -> {
                            readyGo(VipActivity::class.java)
                        }
                        R.id.tv_vip_coin -> {
                            userProfilePresenter.unlockInfoByCoin(toUid)
                        }
                        else -> {}
                    }
                }
            }).show()
        }
    }

    private fun showUnlockWechatDialog() {
        userProfileData?.let {
            UnlockWechatDialog(this, it.headerUrl, object : DialogListener() {
                override fun onClick(dialog: Dialog?, v: View?) {
                    super.onClick(dialog, v)
                    dialog?.dismiss()
                    when (v?.id) {
                        R.id.tv_vip_btn -> {
                            readyGo(VipActivity::class.java)
                        }
                        R.id.tv_vip_coin -> {
                            userProfilePresenter.unlockWechat(toUid)
                        }
                        else -> {}
                    }
                }
            }).show()
        }
    }

    private fun showProfileCountDialog(count: Int) {
        ProfileCountDialog(this, count, object : DialogListener() {
            override fun onClick(dialog: Dialog?, v: View?) {
                super.onClick(dialog, v)
                dialog?.dismiss()
                when (v?.id) {
                    R.id.tv_vip_btn -> {
                        readyGo(VipActivity::class.java)
                    }
                    R.id.tv_vip_coin -> {
                        userProfilePresenter.unlockInfoByCoin(toUid)
                    }
                    else -> {}
                }
            }
        }).show()
    }

    private fun showToBlackDialog() {
        userProfileData?.let {
            ToBlackDialog(this, it.black == 0, object : DialogListener() {
                override fun onClick(dialog: Dialog?, v: View?) {
                    super.onClick(dialog, v)
                    dialog?.dismiss()
                    when (v?.id) {
                        R.id.tv_to_black -> {
                            if (it.black == 1) {
                                userProfilePresenter.toWhite("" + it.uid)
                            } else {
                                Handler(Looper.getMainLooper()).postDelayed({

                                    ToBlackConfirmDialog(this@UserProfileActivity,
                                        object : DialogListener() {
                                            override fun onClick(dialog: Dialog?, v: View?) {
                                                super.onClick(dialog, v)
                                                dialog?.dismiss()
                                                if (v?.id == R.id.tv_confirm) {
                                                    userProfilePresenter.toBlack("" + it.uid)
                                                }
                                            }
                                        }).show()
                                }, 500)
                            }
                        }
                    }
                }
            }).show()
        }
    }

    private fun initAppBar() {
        appbar.addOnOffsetChangedListener(AppBarLayout.OnOffsetChangedListener { appBarLayout, verticalOffset ->
            //verticalOffset  当前偏移量 appBarLayout.getTotalScrollRange() 最大高度 便宜值
            val offset = abs(verticalOffset) //目的是将负数转换为绝对正数；

            if (userIsMale) {

            } else {
                // 标题栏的渐变
                toolbar.setBackgroundColor(
                    changeAlpha(
                        resources.getColor(R.color.color_232122),
                        abs(verticalOffset * 1.0f) / appBarLayout.totalScrollRange
                    )
                )
            }

            /**
             * 当前最大高度 在减去已偏移值 获取浮动 先显示在隐藏
             */
            if (offset < appBarLayout.totalScrollRange) {
                ll_head_center.alpha =
                    1 - (appBarLayout.totalScrollRange - offset * 1.0f) / (appBarLayout.totalScrollRange)
            } else if (offset > appBarLayout.totalScrollRange) {
                val floate =
                    (offset - appBarLayout.totalScrollRange) * 1.0f / (appBarLayout.totalScrollRange)
                ll_head_center.alpha = 1 - floate
            }
        })
    }

    private fun playCollectAnim(view: LottieAnimationView) {
        val lottieDrawable = LottieDrawable()
        LottieCompositionFactory.fromAsset(context, "home_collect.json")
            .addListener { result: LottieComposition? ->
                lottieDrawable.setImagesAssetsFolder("images/")
                lottieDrawable.composition = result
                lottieDrawable.loop(false)
                lottieDrawable.playAnimation()
            }
        view.setImageDrawable(lottieDrawable)
    }

    private fun playCancelCollectAnim(view: LottieAnimationView) {
        val lottieDrawable = LottieDrawable()
        LottieCompositionFactory.fromAsset(context, "home_cancel_collect.json")
            .addListener { result: LottieComposition? ->
                lottieDrawable.setImagesAssetsFolder("images/")
                lottieDrawable.composition = result
                lottieDrawable.loop(false)
                lottieDrawable.playAnimation()
            }
        view.setImageDrawable(lottieDrawable)
    }

    /**
     * 根据百分比改变颜色透明度
     */
    fun changeAlpha(color: Int, fraction: Float): Int {
        val alpha = (Color.alpha(color) * fraction).toInt()
        return Color.argb(alpha, 35, 33, 34)
    }

    private fun setViewBlur() {
        blurview.visibility = View.VISIBLE
        blurview?.refreshView(
            ShapeBlurView.build(this).setBlurMode(BlurMode.MODE_RECTANGLE)
        )
    }
}
