package com.duben.roseplaylet.ui.activitys

import android.content.Intent
import android.graphics.Color
import android.net.Uri
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import com.alipay.sdk.app.OpenAuthTask
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.AppConfig
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.manager.UserManager
import com.duben.roseplaylet.mvp.model.AlipayMsgBean
import com.duben.roseplaylet.mvp.model.DrawCashBean
import com.duben.roseplaylet.mvp.model.VipBean
import com.duben.roseplaylet.mvp.model.WxPayParamBean
import com.duben.roseplaylet.mvp.presenters.DrawCashPresenter
import com.duben.roseplaylet.mvp.views.DrawCashView
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.roseplaylet.ui.adapter.CoinAdapter
import com.jobo.alipay.AliPay
import com.jobo.alipay.AlipayInfoImpl
import com.jobo.rxpay.RxPay
import com.jobo.rxpay.callback.IPayCallback
import com.jobo.wxpay.WXPay
import com.jobo.wxpay.WXPayInfoImpl
import com.tencent.mm.opensdk.modelbiz.WXLaunchMiniProgram
import com.tencent.mm.opensdk.openapi.IWXAPI
import com.tencent.mm.opensdk.openapi.WXAPIFactory
import kotlinx.android.synthetic.main.activity_wallet.*
import kotlinx.android.synthetic.main.header_layout.*
import java.net.URLEncoder

/**
 *  @author Assen
 *  @date 2024/1/8
 *  @desc 钱包
 */
class WalletActivity : BaseActivity(), View.OnClickListener, DrawCashView {

    private val userManager by lazy { UserManager.getInstance() }

    private lateinit var coinAdapter: CoinAdapter
    private var beansData: MutableList<VipBean.ListBean> = mutableListOf()
    private val drawCashPresenter by lazy { DrawCashPresenter() }

    override fun getContentViewLayoutID() = R.layout.activity_wallet

    override fun onResume() {
        super.onResume()
        if (UserManager.getInstance().vipFlag) {
            ll_vip_container.visibility = View.GONE
        } else {
            ll_vip_container.visibility = View.VISIBLE
        }
    }

    override fun initViewsAndEvents() {
        drawCashPresenter.attachView(this)

        initHeader()
        initView()
        initRecy()
        initListener()

        drawCashPresenter.getVipProducts()
    }

    private fun initView() {
        tv_balance.text = "" + userManager.userBeans
        tv_cash.text = "" + userManager.userRewardCash
    }

    private fun initRecy() {
        coinAdapter = CoinAdapter()
        coinAdapter.animationEnable = false
        val emptyView = LayoutInflater.from(this).inflate(R.layout.item_empty_data, null)
        coinAdapter.setEmptyView(emptyView)
        coinAdapter.setOnItemClickListener { adapter, view, position ->
            coinAdapter.setPosition(position)
        }
        rv_wallet_coin.layoutManager = GridLayoutManager(this, 3)
        rv_wallet_coin.adapter = coinAdapter
    }

    private fun initHeader() {
        tv_title.text = "钱包"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        line.visibility = View.GONE
        tv_right.visibility = View.VISIBLE
        tv_right.text = "明细"
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tv_right.setOnClickListener(this)
        tv_cash_label.setOnClickListener(this)

        tv_go_vip.setOnClickListener(this)
        tv_go_share.setOnClickListener(this)
        tv_contact_us.setOnClickListener(this)

        btn_alipay.setOnClickListener(this)
        btn_wxpay.setOnClickListener(this)
    }

    override fun isApplyKitKatTranslucency() = false

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.tv_right -> {

            }
            R.id.tv_cash_label -> {
                readyGo(DrawCashActivity::class.java)
            }
            R.id.tv_go_vip -> {
                readyGo(VipActivity::class.java)
            }
            R.id.tv_contact_us -> {
                // TODO 联系我们
            }
            R.id.tv_go_share -> {
                readyGo(ShareActivity::class.java)
            }
            R.id.btn_alipay -> {
                // 支付宝支付
                beansData.let {
                    val vipBean = it[coinAdapter.getPosition()]
                    drawCashPresenter.getVipPayParams(
                        Constant.ALI_PAY,
                        vipBean.pid,
                        VipActivity.ENTER_TYPE_ACTIVITY
                    )
                }
            }
            R.id.btn_wxpay -> {
                // 微信支付
                beansData.let {
                    val vipBean = it[coinAdapter.getPosition()]
                    drawCashPresenter.getVipPayParams(
                        Constant.WECHAT_PAY,
                        vipBean.pid,
                        VipActivity.ENTER_TYPE_ACTIVITY
                    )
                }
            }
        }
    }

    override fun getVipProductSuc(data: VipBean) {
        if (data.beansList.isEmpty()) return
        beansData = data.beansList
        coinAdapter.setNewInstance(data.beansList)
    }

    override fun getCashouBaseMsgSuc(data: DrawCashBean) {}

    override fun getCashouBaseMsgFail() {}

    override fun addCashoutReqSuc() {}

    override fun addCashoutReqFail() {}

    override fun getAlipayMsgSuc(data: AlipayMsgBean) {}

    override fun getAlipayMsgFail() {}

    override fun queryVipOrderSuc(isPay: Boolean) {
        if (isFinishing) return

        if (isPay) {
            showToast("支付成功")
            if (!UserManager.getInstance().userIsLogin()) {
                val b = Bundle()
                b.putString(BindMobileActivity.TYPE, "vip")
                readyGoThenKill(BindMobileActivity::class.java, b)
            } else {
                readyGoThenKill(MainActivity::class.java)
            }
        }
    }

    override fun getVipPayParamsSuc(payChannel: String, paramsBean: WxPayParamBean, enter: String) {
        if (!isFinishing) {
            if (TextUtils.equals(payChannel, Constant.WECHAT_PAY)) {
                if (paramsBean.params == null) {
                    showToast("微信支付维护中")
                    return
                }

                wxPay(paramsBean)
            } else {
                if (paramsBean.params == null) {
                    showToast("支付宝支付维护中")
                    return
                }

                if (beansData.size > 0) {
                    val vipBean = beansData[coinAdapter.getPosition()]
                    //0 app内部，1.只签约转支付宝浏览器支付 2.带uid转支付宝小程序(暂定只有一个小程序)
                    when (vipBean.payToModel) {
                        0 -> {
                            alipay(paramsBean)
                        }
                        1 -> {
                            openAutoAlipay(paramsBean.params.params)
                        }
                        2 -> {
                            if (TextUtils.equals(VipActivity.ENTER_TYPE_ACTIVITY, enter)) {
                                openAlipayApp(vipBean.payToModel2FirstAlipayAppid)
                            } else {
                                openAlipayApp(vipBean.payToModel2SecondAlipayAppid)
                            }
                        }
                        4 -> {
                            goAlipaySignExecute(paramsBean.params.params)
                        }
                    }
                }
            }
        }
    }

    override fun updateAlipayMsgSuc() {}

    override fun updateAlipayMsgFail() {}

    fun wxPay(wxParanBean: WxPayParamBean) {
        val data = wxParanBean.params
        //实例化微信支付策略
        val wxPay: WXPay = WXPay.getInstance()
        //构造微信订单实体。一般都是由服务端直接返回。
        val wxPayInfoImpl = WXPayInfoImpl()
        wxPayInfoImpl.timestamp = data.timestamp
        wxPayInfoImpl.sign = data.sign
        wxPayInfoImpl.prepayId = data.prepayid
        wxPayInfoImpl.partnerid = data.partnerid
        wxPayInfoImpl.appid = VipActivity.wxAppId
        wxPayInfoImpl.nonceStr = data.noncestr
        wxPayInfoImpl.packageValue = data.packageX
        //策略场景类调起支付方法开始支付，以及接收回调。
        RxPay.pay(wxPay, this, wxPayInfoImpl, object : IPayCallback {
            override fun success() {
                drawCashPresenter.queryVipOrder(wxParanBean.tid.toString(), true)
            }

            override fun failed(code: Int, message: String?) {
                drawCashPresenter.queryVipOrder(wxParanBean.tid.toString(), false)
            }

            override fun cancel() {
                drawCashPresenter.queryVipOrder(wxParanBean.tid.toString(), false)
            }
        })
    }

    fun alipay(wxParanBean: WxPayParamBean) {
        //实例化支付宝支付策略
        val aliPay = AliPay()
        //构造支付宝订单实体。一般都是由服务端直接返回。
        val alipayInfoImpl = AlipayInfoImpl()
        alipayInfoImpl.setOrderInfo(wxParanBean.params.params)
        //策略场景类调起支付方法开始支付，以及接收回调。
        RxPay.pay(aliPay, this, alipayInfoImpl, object : IPayCallback {
            override fun success() {
                drawCashPresenter.queryVipOrder(wxParanBean.tid.toString(), true)
            }

            override fun failed(code: Int, message: String?) {
                drawCashPresenter.payError(code)
                if (!TextUtils.isEmpty(message)) {
                    showToast(message)
                }
            }

            override fun cancel() {
                drawCashPresenter.queryVipOrder(wxParanBean.tid.toString(), false)
            }
        })
    }

    /**
     * 自动续费
     */
    fun openAutoAlipay(url: String) {
        AppConfig.enterAlipay = true
        val intent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
        startActivity(intent)
    }

    /**
     * 跳转支付宝小程序
     */
    private fun openAlipayApp(alipayAppId: String) {
        AppConfig.enterAlipay = true
        try {
            val path =
                "app_uid=" + UserManager.getInstance().userID + "&package_app=" + Constant.MINTS_PKG_NAME//这里是传的参数
            val link = URLEncoder.encode(path, "UTF-8")//这里是encode传的参数
            val url =
                "alipays://platformapi/startapp?appId=$alipayAppId&page=pages/loading&query=$link"
            val uri = Uri.parse(url) // url为你要链接的地址
            val intent = Intent(Intent.ACTION_VIEW, uri)
            startActivity(intent)
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    private fun openWxApp() {
        try {
            val appId = "wx263e5304a9a67d7c" // 填移动应用(App)的 AppId，非小程序的 AppID
            val api: IWXAPI = WXAPIFactory.createWXAPI(context, appId)
            val req = WXLaunchMiniProgram.Req()
            req.userName = "gh_439c32026e1b" // 填小程序原始id
            req.path =
                "/pages/loading?testApp1=mcg1&testApp2=mcg2" ////拉起小程序页面的可带参路径，不填默认拉起小程序首页，对于小游戏，可以只传入 query 部分，来实现传参效果，如：传入 "?foo=bar"。
            req.miniprogramType =
                WXLaunchMiniProgram.Req.MINIPTOGRAM_TYPE_RELEASE // 可选打开 开发版，体验版和正式版
            api.sendReq(req)
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }


    /**
     * 唤起独立签约-拿到结果
     *
     * @param signParams
     */
    private fun goAlipaySignExecute(signParams: String) {
        AppConfig.enterAlipay = true
        try {
            val openAuthTask = OpenAuthTask(this)
            val map: MutableMap<String, String> = HashMap()
            map["sign_params"] = signParams
            openAuthTask.execute(
                "com.duben.roseplaylet.ui.activitys.WalletActivity",
                OpenAuthTask.BizType.Deduct,
                map,
                { resultCode: Int, memo: String?, bundle: Bundle ->
                    if (resultCode == OpenAuthTask.OK) {
                        // 对业务完成的结果做后续处理
                    } else {
                        // 对业务失败的结果做后续处理
                        showToast("支付失败")
                    }
                },
                true
            )
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

}