package com.duben.roseplaylet.ui.adapter

import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.airbnb.lottie.LottieAnimationView
import com.airbnb.lottie.LottieComposition
import com.airbnb.lottie.LottieCompositionFactory
import com.airbnb.lottie.LottieDrawable
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.viewholder.BaseViewHolder
import com.duben.library.utils.GlideUtils
import com.duben.roseplaylet.R
import com.duben.roseplaylet.mvp.model.*

class CommonListAdapter : BaseQuickAdapter<UserData, BaseViewHolder>(R.layout.item_common_data) {

    private var isBlur = false
    private var isLike = false

    override fun convert(holder: BaseViewHolder, item: UserData) {
        holder.getView<TextView>(R.id.tv_recommend_name).text = item.nickName
        holder.getView<TextView>(R.id.tv_recommend_info).text =
            item.age + " " + item.lastCity + " " + item.career

        val tvRealLabel = holder.getView<TextView>(R.id.tv_real_label)
        if (item.idcardStatus == 1) {
            tvRealLabel.visibility = View.VISIBLE
        } else {
            tvRealLabel.visibility = View.GONE
        }

        if (isBlur) {
            GlideUtils.loadBlurImageView(
                holder.itemView.context,
                item.headerUrl,
                holder.getView(R.id.iv_recommend_header)
            )
        } else {
            GlideUtils.loadImageViewNoAnim2(
                holder.itemView.context,
                item.headerUrl,
                holder.getView(R.id.iv_recommend_header)
            )
        }

        val viewDate = holder.getView<TextView>(R.id.tv_recommend_date)
        val viewHeart = holder.getView<LottieAnimationView>(R.id.iv_recommend_heart)

        if (isLike) {
            viewHeart.visibility = View.VISIBLE
            viewDate.visibility = View.GONE
            if (item.likeStatus == 0) {
                playCancelCollectAnim(viewHeart)
            } else {
                playCollectAnim(viewHeart)
            }
            holder.getView<ImageView>(R.id.iv_recommend_heart).setOnClickListener {
                mOnClickLikeListener?.onClickLike(holder.adapterPosition)

                if (item.likeStatus == 0) {
                    playCollectAnim(holder.getView(R.id.iv_recommend_heart))
                } else {
                    playCancelCollectAnim(holder.getView(R.id.iv_recommend_heart))
                }
            }
        } else {
            viewDate.text = item.rtime
            viewHeart.visibility = View.GONE
            viewDate.visibility = View.VISIBLE
        }

    }

    fun setIsBlur(isBlur: Boolean) {
        this.isBlur = isBlur
    }

    fun setIsLike(isLike: Boolean) {
        this.isLike = isLike
    }

    private fun playCollectAnim(view: LottieAnimationView) {
        val lottieDrawable = LottieDrawable()
        LottieCompositionFactory.fromAsset(context, "home_collect.json")
            .addListener { result: LottieComposition? ->
                lottieDrawable.setImagesAssetsFolder("images/")
                lottieDrawable.composition = result
                lottieDrawable.repeatCount = 0
                lottieDrawable.playAnimation()
            }
        view.setImageDrawable(lottieDrawable)
    }

    private fun playCancelCollectAnim(view: LottieAnimationView) {
        val lottieDrawable = LottieDrawable()
        LottieCompositionFactory.fromAsset(context, "home_cancel_collect.json")
            .addListener { result: LottieComposition? ->
                lottieDrawable.setImagesAssetsFolder("images/")
                lottieDrawable.composition = result
                lottieDrawable.repeatCount = 0
                lottieDrawable.playAnimation()
            }
        view.setImageDrawable(lottieDrawable)
    }

    private var mOnClickLikeListener: OnClickLikeListener? = null

    fun setOnClickLikeListener(onClickLikeListener: OnClickLikeListener) {
        this.mOnClickLikeListener = onClickLikeListener
    }

    interface OnClickLikeListener {
        fun onClickLike(position: Int)
    }
}