package com.duben.roseplaylet.ui.adapter

import android.content.Intent
import android.os.Bundle
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.airbnb.lottie.LottieAnimationView
import com.airbnb.lottie.LottieComposition
import com.airbnb.lottie.LottieCompositionFactory
import com.airbnb.lottie.LottieDrawable
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.viewholder.BaseViewHolder
import com.duben.library.utils.GlideUtils
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.mvp.model.HallList
import com.duben.roseplaylet.ui.activitys.UserProfileActivity

class SquareAdapter : BaseQuickAdapter<HallList.ListDTO, BaseViewHolder>(R.layout.item_square) {

    private var isBlur = false

    override fun convert(holder: BaseViewHolder, item: HallList.ListDTO) {
        holder.getView<TextView>(R.id.tv_recommend_name).text = item.nickName
        holder.getView<TextView>(R.id.tv_status).text = item.hallTime
        holder.getView<TextView>(R.id.tv_recommend_location).text = "" + item.distance + "km"

        val tvRealLabel = holder.getView<TextView>(R.id.tv_real_label)
        if (item.idcardStatus == 1) {
            tvRealLabel.visibility = View.VISIBLE
        } else {
            tvRealLabel.visibility = View.GONE
        }

        if (isBlur) {
            GlideUtils.loadBlurImageView(
                holder.itemView.context,
                item.headerUrl,
                holder.getView(R.id.iv_recommend_header)
            )
        } else {
            GlideUtils.loadImageViewNoAnim2(
                holder.itemView.context,
                item.headerUrl,
                holder.getView(R.id.iv_recommend_header)
            )
        }

        val view = holder.getView<LottieAnimationView>(R.id.iv_heart)
        if (item.likeStatus == 0) {
            playCancelCollectAnim(view)
        } else {
            playCollectAnim(view)
        }

        holder.getView<ImageView>(R.id.iv_heart).setOnClickListener {
            mOnClickLikeListener?.onClickLike(holder.adapterPosition)

            if (item.likeStatus == 0) {
                playCollectAnim(holder.getView(R.id.iv_heart))
            } else {
                playCancelCollectAnim(holder.getView(R.id.iv_heart))
            }
        }

        holder.itemView.setOnClickListener {
            val intent = Intent(it.context, UserProfileActivity::class.java)
            val bundle = Bundle()
            bundle.putString(Constant.TO_UID, item.uid.toString())
            intent.putExtras(bundle)
            it.context.startActivity(intent)
        }
    }

    fun setIsBlur(isBlur: Boolean) {
        this.isBlur = isBlur
    }


    private fun playCollectAnim(view: LottieAnimationView) {
        val lottieDrawable = LottieDrawable()
        LottieCompositionFactory.fromAsset(context, "home_collect.json")
            .addListener { result: LottieComposition? ->
                lottieDrawable.setImagesAssetsFolder("images/")
                lottieDrawable.composition = result
                lottieDrawable.loop(false)
                lottieDrawable.playAnimation()
            }
        view.setImageDrawable(lottieDrawable)
    }

    private fun playCancelCollectAnim(view: LottieAnimationView) {
        val lottieDrawable = LottieDrawable()
        LottieCompositionFactory.fromAsset(context, "home_cancel_collect.json")
            .addListener { result: LottieComposition? ->
                lottieDrawable.setImagesAssetsFolder("images/")
                lottieDrawable.composition = result
                lottieDrawable.loop(false)
                lottieDrawable.playAnimation()
            }
        view.setImageDrawable(lottieDrawable)
    }


    private var mOnClickLikeListener: OnClickLikeListener? = null

    fun setOnClickLikeListener(onClickLikeListener: OnClickLikeListener) {
        this.mOnClickLikeListener = onClickLikeListener
    }

    interface OnClickLikeListener {
        fun onClickLike(position: Int)
    }
}