package com.duben.roseplaylet.ui.adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.duben.library.utils.GlideUtils
import com.duben.roseplaylet.R
import com.duben.roseplaylet.ui.adapter.base.OnItemClickListener
import com.duben.roseplaylet.utils.LogUtil

class UserProfileAlbumAdapter(val context: Context, val images: List<String>) :
    RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    companion object {
        const val HOLDER_TYPE_EMPTY = 0
        const val HOLDER_TYPE_IMAGE = 1
    }

    private var isShowAuth = false
    private var mOnItemClickListener: OnItemClickListener? = null

    fun showAuth(showAuth: Boolean) {
        this.isShowAuth = showAuth
    }

    fun setOnItemClickListener(listener: OnItemClickListener) {
        mOnItemClickListener = listener
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        if (viewType == OrderRecordAdapter.HOLDER_TYPE_EMPTY) {
            val emptyView =
                LayoutInflater.from(parent.context).inflate(R.layout.item_empty_cash, parent, false)
            return EmptyHolder(emptyView)
        }

        val view = LayoutInflater.from(parent.context)
            .inflate(R.layout.item_user_profile_album, parent, false)
        return ViewHolder(view)
    }

    inner class ViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val tv_auth: TextView = view.findViewById(R.id.tv_auth)
        val iv_photo: ImageView = view.findViewById(R.id.iv_photo)
    }

    inner class EmptyHolder(itemView: View) : RecyclerView.ViewHolder(itemView)

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        if (holder is EmptyHolder) {
            return
        }

        val myholder = holder as ViewHolder
        if (isShowAuth) {
            myholder.tv_auth.visibility = View.VISIBLE
        } else {
            myholder.tv_auth.visibility = View.GONE
        }
        myholder.iv_photo.setOnClickListener {
            mOnItemClickListener?.onItemClick(it, position)
        }
        LogUtil.d("AAAAAA" + images[position])
        GlideUtils.loadImageViewNoAnim2(context, images[position], myholder.iv_photo)
    }

    override fun getItemCount(): Int {
        return if (images.isEmpty()) {
            1
        } else {
            images.size
        }
    }

    override fun getItemViewType(position: Int): Int {
        if (images.isEmpty()) {
            return HOLDER_TYPE_EMPTY
        }
        return HOLDER_TYPE_IMAGE
    }


}