package com.duben.roseplaylet.ui.fragment

import android.view.LayoutInflater
import android.view.View
import android.widget.TextView
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.AppConfig
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.manager.UserManager
import com.duben.roseplaylet.ui.adapter.MsgPageAdapter
import com.duben.roseplaylet.ui.fragment.base.LazyLoadBaseFragment
import com.google.android.material.tabs.TabLayout
import com.google.android.material.tabs.TabLayoutMediator
import com.tencent.qcloud.tuikit.tuiconversation.classicui.page.TUIConversationFragment
import kotlinx.android.synthetic.main.fragment_main_message.*

class MessageFragment : LazyLoadBaseFragment(), View.OnClickListener {

    private val tabsData = arrayListOf<String>()
    private val fragmentsData = mutableListOf<Fragment>()
    private var vpAdapter: MsgPageAdapter? = null

    private val userManager by lazy { UserManager.getInstance() }

    override fun getContentViewLayoutID() = R.layout.fragment_main_message

    override fun initViewsAndEvents() {
        initView()
    }

    private fun initView() {
        tv_clear_noread.setOnClickListener(this)
        tv_clear_list.setOnClickListener(this)

        tabsData.add(String.format("聊天"))
        tabsData.add(String.format("系统消息"))

        fragmentsData.add(TUIConversationFragment())
        fragmentsData.add(SystemMsgFragment())

        vpAdapter = MsgPageAdapter(tabsData, fragmentsData, requireActivity())
        vp2.adapter = vpAdapter

        TabLayoutMediator(tab_msg, vp2) { tab, position ->
            // 初始化Tab
            tab.id = position
            if (tabsData.size > 0) {
                if (position == 0) {
                    tab.customView = getTabView(tabsData[position], true)
                } else {
                    tab.customView = getTabView(tabsData[position], false)
                }
            }
        }.attach()
        tab_msg.addOnTabSelectedListener(object : TabLayout.OnTabSelectedListener {
            override fun onTabSelected(tab: TabLayout.Tab?) {
                tab?.let {
                    updateTab(it.customView, true)
                    if (it.position == 0) {
                        tv_clear_list.visibility = View.VISIBLE
                    } else {
                        tv_clear_list.visibility = View.GONE
                    }
                }
            }

            override fun onTabUnselected(tab: TabLayout.Tab?) {
                tab?.let { updateTab(it.customView, false) }
            }

            override fun onTabReselected(tab: TabLayout.Tab?) {
            }
        })
    }

    private fun updateTab(view: View?, isSelected: Boolean) {
        view?.let {
            val text = it.findViewById<TextView>(R.id.item_tv)
            val bar = it.findViewById<View>(R.id.view_bar)
            if (isSelected) {
                text.setTextColor(ContextCompat.getColor(requireContext(), R.color.color_E4C46C))
                bar.visibility = View.VISIBLE
            } else {
                text.setTextColor(ContextCompat.getColor(requireContext(), R.color.color_959595))
                bar.visibility = View.INVISIBLE
            }
        }
    }

    private fun getTabView(text: String, isSelected: Boolean): View {
        val view = LayoutInflater.from(requireContext()).inflate(R.layout.item_square_tab, null)
        view.findViewById<TextView>(R.id.item_tv).text = text
        updateTab(view, isSelected)
        return view
    }


    override fun onFragmentResume() {
        super.onFragmentResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_FOUR) {

        }
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.tv_clear_noread -> {
                // 清除未读
            }
            R.id.tv_clear_list -> {
                // 清除列表
            }
        }
    }
}