package com.duben.roseplaylet.ui.fragment

import android.os.Bundle
import android.text.TextUtils
import android.view.View
import android.widget.FrameLayout
import androidx.core.content.ContextCompat
import com.duben.library.utils.GlideUtils
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.ad.express.ExpressAdCallback
import com.duben.roseplaylet.ad.express.MyExpressManager
import com.duben.roseplaylet.common.AppConfig
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.manager.UserManager
import com.duben.roseplaylet.mvp.model.UserBean
import com.duben.roseplaylet.mvp.model.UserHallMsg
import com.duben.roseplaylet.mvp.presenters.MyPresenter
import com.duben.roseplaylet.mvp.views.MyView
import com.duben.roseplaylet.ui.activitys.*
import com.duben.roseplaylet.ui.fragment.base.LazyLoadBaseFragment
import com.duben.roseplaylet.utils.SpanUtils
import com.duben.roseplaylet.utils.UIUtils
import kotlinx.android.synthetic.main.fragment_main_my.*

class MyFragment : LazyLoadBaseFragment(), MyView, View.OnClickListener {

    private val myPresenter by lazy { MyPresenter() }
    private val userManager by lazy { UserManager.getInstance() }

    private var toUid = ""

    override fun getContentViewLayoutID() = R.layout.fragment_main_my

    override fun initViewsAndEvents() {
        myPresenter.attachView(this)
        initView()
        initListener()
    }

    private fun initView() {
        tv_contact.text = SpanUtils()
            .append("如有问题，请直接联系")
            .append("在线客服\n")
            .setForegroundColor(ContextCompat.getColor(requireContext(), R.color.color_E8CF83))
            .append("处理速度更快，")
            .append("无需联系支付宝")
            .setForegroundColor(ContextCompat.getColor(requireContext(), R.color.color_E8CF83))
            .create()
    }

    override fun onDestroy() {
        super.onDestroy()
        myPresenter.detachView()
    }

    override fun onFragmentResume() {
        super.onFragmentResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_FIVE) {
            if (AntiShake.check(ll_edit_profile?.id)) return
            if (userManager.vipFlag) {
                MyExpressManager.instance.preLoadAd()
                showAd()
            }
            if (!TextUtils.isEmpty(userManager?.userID)) {
                myPresenter.getBaseMsg()
            } else {
                myPresenter.userLogin()
            }
        }
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.ll_edit_profile -> {
                readyGo(EditProfileActivity::class.java)
            }
            R.id.ll_my_vip -> {
                if (!userManager.vipFlag) {
                    readyGo(VipActivity::class.java)
                }
            }
            R.id.ll_my_ilike -> {
                val bundle = Bundle()
                bundle.putInt(Constant.USER_COMMON_DATA_TYPE, 0)
                readyGo(CommonDataActivity::class.java, bundle)
            }
            R.id.ll_my_likeme -> {
                val bundle = Bundle()
                bundle.putInt(Constant.USER_COMMON_DATA_TYPE, 1)
                readyGo(CommonDataActivity::class.java, bundle)
            }
            R.id.ll_my_seeme -> {
                val bundle = Bundle()
                bundle.putInt(Constant.USER_COMMON_DATA_TYPE, 2)
                readyGo(CommonDataActivity::class.java, bundle)
            }
            R.id.ll_my_wallet -> {
                readyGo(WalletActivity::class.java)
            }
            R.id.ll_my_invite -> {
                readyGo(ShareActivity::class.java)
            }
            R.id.ll_my_album -> {
                readyGo(AlbumActivity::class.java)
            }
            R.id.ll_my_auth -> {
                readyGo(AuthCenterActivity::class.java)
            }
            R.id.ll_my_community -> {}
            R.id.ll_my_wechat -> {}
            R.id.ll_my_contactus -> {
                (requireActivity() as MainActivity).backPhoneDialog()
            }
            R.id.ll_my_feedback -> {
                readyGo(FeedbackActivity::class.java)
            }
            R.id.ll_my_settings -> {
                readyGo(SettingsActivity::class.java)
            }
//            R.id.tv_my_account -> {
//                if (!userManager.userIsLogin()) {
//                    readyGo(BindMobileActivity::class.java)
//                }
//            }
        }
    }

    override fun getBaseMsgSuc(data: UserBean) {
        toUid = data.idcode
        tv_my_nickname.text = data.nickName
        tv_my_label.text = "" + data.age + "岁 " + data.city
        tv_my_id.text = "ID:" + data.idcode
        GlideUtils.loadImageView(requireContext(), data.headerUrl, civ_my_avatar)

        if (data.sex == 1) {
            // 男性无认证页面
            ll_my_auth.visibility = View.GONE
            // 男性展示充值的金币
            tv_my_coin.text = "" + data.beans
        } else {
            // 女性展示奖励的金币
            tv_my_coin.text = "" + data.rewardCoin

            if (data.idcardStatus == 0) {
                // 女性展示认证页面
                ll_my_auth.visibility = View.VISIBLE
            } else {
                ll_my_auth.visibility = View.GONE
            }
        }
    }

    override fun getUserHallMsgSuc(data: UserHallMsg) {
        tv_my_ilike.text = "" + data.like_count
        tv_my_likeme.text = "" + data.likeme_count
        tv_my_seeme.text = "" + data.seeme_count
        tv_my_album_count.text = "" + data.image_count + "张"
    }

    private fun initListener() {
        ll_edit_profile.setOnClickListener(this)
        ll_my_ilike.setOnClickListener(this)
        ll_my_likeme.setOnClickListener(this)
        ll_my_seeme.setOnClickListener(this)
        ll_my_vip.setOnClickListener(this)
        ll_my_wallet.setOnClickListener(this)
        ll_my_invite.setOnClickListener(this)
        ll_my_album.setOnClickListener(this)
        ll_my_auth.setOnClickListener(this)
        ll_my_community.setOnClickListener(this)
        ll_my_wechat.setOnClickListener(this)
        ll_my_contactus.setOnClickListener(this)
        ll_my_feedback.setOnClickListener(this)
        ll_my_settings.setOnClickListener(this)
    }

    private fun showAd() {
        MyExpressManager.instance.getAdView(object : ExpressAdCallback {
            override fun loadSuccess(adView: FrameLayout?) {
                adView?.let {
                    UIUtils.removeFromParent(it)
                    fl_ad.removeAllViews()
                    fl_ad.addView(it)
                }

                MyExpressManager.instance.preLoadAd()
            }

            override fun renderSuccess(adView: FrameLayout?): Boolean {
                adView?.let {
                    UIUtils.removeFromParent(it)
                    fl_ad.removeAllViews()
                    fl_ad.addView(it)
                }

                MyExpressManager.instance.preLoadAd()
                return false
            }

            override fun loadFail() {
            }
        })
    }

}