package com.duben.roseplaylet.ui.widgets

import android.app.Dialog
import android.content.Context
import android.view.Gravity
import android.view.KeyEvent
import android.view.View
import android.view.WindowManager
import android.widget.ImageView
import android.widget.TextView
import com.duben.roseplaylet.R
import com.duben.roseplaylet.utils.SpanUtils

class ProfileCountDialog(
    private val context: Context,
    val count: Int = 0,
    private val listener: DialogListener?
) :
    Dialog(context, R.style.dialog) {
    private val lp: WindowManager.LayoutParams

    private val tv_free_count: TextView
    private val tv_vip_btn: TextView
    private val tv_vip_coin: TextView
    private val iv_close: ImageView

    init {
        setContentView(R.layout.dialog_profile_count)
        // 设置window属性
        lp = window!!.attributes
        lp.gravity = Gravity.CENTER
        lp.width = WindowManager.LayoutParams.MATCH_PARENT
        lp.windowAnimations = R.style.DialogAnimFade
        window!!.attributes = lp

        // 设置外部不可关闭
        setCancelable(false)
        setCanceledOnTouchOutside(false)
        setOnKeyListener { _, i, _ -> i == KeyEvent.KEYCODE_BACK }

        tv_vip_btn = findViewById<View>(R.id.tv_vip_btn) as TextView
        tv_vip_coin = findViewById<View>(R.id.tv_vip_coin) as TextView
        tv_free_count = findViewById<View>(R.id.tv_free_count) as TextView

        if (count > 0) {
            tv_free_count.text = SpanUtils()
                .append("你今天免费的查看次数还剩")
                .append("" + count + "次")
                .setForegroundColor(context.resources.getColor(R.color.color_E8C46E))
                .create()
        } else {
            tv_free_count.text = "你今天免费的查看次数已用完"
        }
        iv_close = findViewById<View>(R.id.iv_close) as ImageView
        iv_close.setOnClickListener {
            dismiss()
        }

        listener?.setDialog(this)
        tv_vip_btn.setOnClickListener(listener)
        tv_vip_coin.setOnClickListener(listener)
    }
}