package com.duben.roseplaylet.ui.widgets.nineImage

import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.FrameLayout
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.duben.roseplaylet.R

class AddImagesView @JvmOverloads constructor(
    mContext: Context,
    attrs: AttributeSet? = null,
    defStyleAttr: Int = 0
) : FrameLayout(mContext, attrs, defStyleAttr) {
    private var mContext: Context

    // 添加的图片资源
    private var addImgs = -1

    //关闭的图片资源
    private var addCloseImgs = -1

    //错误页的图片资源
    private var addErrImgs = -1

    //列数
    private var columnNums = 5

    //最大图片数
    private var add_limit_nums = 9

    private lateinit var mAdapter: AddImagesAdapter

    init {
        this.mContext = mContext
        val tapeArray = mContext.obtainStyledAttributes(attrs, R.styleable.AddImagesStyle)
        addImgs = tapeArray.getResourceId(R.styleable.AddImagesStyle_add_imgs, -1)
        addCloseImgs = tapeArray.getResourceId(R.styleable.AddImagesStyle_add_close_imgs, -1)
        addErrImgs = tapeArray.getResourceId(R.styleable.AddImagesStyle_add_err_imgs, -1)
        columnNums = tapeArray.getInt(R.styleable.AddImagesStyle_column_nums, 5)
        add_limit_nums = tapeArray.getInt(R.styleable.AddImagesStyle_add_limit_nums, 9)
        initView()
    }

    var listener: AddImagesViewListener? = null

    fun setAddImagesViewListener(listener: AddImagesViewListener) {
        this.listener = listener
    }

    //初始换数据
    private fun initView() {
        val rootView =
            LayoutInflater.from(mContext).inflate(R.layout.layout_add_images, this, false)
        val rvContent = rootView.findViewById<RecyclerView>(R.id.rv_content)

        addView(rootView)
        if (columnNums > 5) columnNums = 5
        rvContent.layoutManager = GridLayoutManager(mContext, columnNums)
        mAdapter = AddImagesAdapter(
            mContext,
            columnNums,
            addImgs,
            addCloseImgs,
            addErrImgs,
            add_limit_nums
        )
        rvContent.adapter = mAdapter
        mAdapter.addItem(AddImagesInfo("", "1"))
        mAdapter.setOnAddListener(object : AddImagesAdapter.OnAddClickListener {
            override fun onAddClick(view: View?, position: Int) {
                when (view?.id) {
                    R.id.rl_add -> {
                        listener?.onAdd()
                    }
                    R.id.iv_content -> {
                        listener?.onPreview(position, mAdapter.getItems())
                    }
                }
            }

            override fun onLongClick(item: AddImagesInfo?) {
                listener?.onLongClick(item)
            }

            override fun onDeleteClick(position: Int) {
                listener?.onDelete(position)
            }
        })
    }

    //添加数据
    fun addAddImages(lists: List<AddImagesInfo>) {
        mAdapter.addItems(lists)
    }

    fun getAddImages(): List<AddImagesInfo> {
        return mAdapter.getItems()
    }

    fun enableCloseView(enable: Boolean) {
        mAdapter.enableClose(enable)
    }

    fun deleteImage(item: AddImagesInfo?) {
        mAdapter.processDelete(item)
    }

    interface AddImagesViewListener {
        fun onAdd()
        fun onDelete(position: Int)
        fun onLongClick(item: AddImagesInfo?)
        fun onPreview(position: Int, lists: List<AddImagesInfo>?)
    }

}